from django.urls import path, include
from . import views

urlpatterns = [
	### Staff
	path('s/list/', views.sLeaveList, name="leave-s-list"),
	path('s/detail/<str:hashid>/', views.sLeaveDetail, name="leave-s-detail"),
	path('s/leave/pdf/<str:hashid>/', views.sLeavePDF, name="leave-s-pdf"),
	path('terminate/<str:hashid>/', views.LeaveTerminate, name="leave-terminate"),
	#
	path('add/', views.LeaveAdd, name="leave-add"),
	path('update/<str:hashid>/', views.LeaveUpdate, name="leave-update"),
	path('lock/<str:hashid>/', views.LeaveLock, name="leave-lock"),
	path('unlock/<str:hashid>/', views.LeaveUnLock, name="leave-unlock"),
	path('send/<str:hashid>/', views.LeaveSend, name="leave-send"),
	path('balance/check/', views.sLeaveBalCheck, name="leave-bal-check"),
	#
	path('deleg/list/', views.LeaveDelegList, name="leave-deleg-list"),
	path('deleg/update/<str:hashid>/', views.LeaveDelegUpdate, name="leave-deleg-update"),
	path('deleg/confirm/<str:hashid>/', views.LeaveDelegConfirm, name="leave-deleg-confirm"),
	path('deleg/confirm2/<str:hashid>/', views.LeaveDelegConfirm2, name="leave-deleg-confirm2"),
	path('deleg/cancel/<str:hashid>/', views.LeaveDelegCancel, name="leave-deleg-cancel"),
	path('deleg/detail/<str:hashid>/', views.LeaveDelegDetail, name="leave-deleg-detail"),
	################################################################
	path('dep/list/', views.LeaveDepList, name="leave-dep-list"),
	path('dep/aprv/list/', views.LeaveDepAprvList, name="leave-dep-aprv-list"),
	path('dep/detail/<str:hashid>/', views.LeaveDepDetail, name="leave-dep-detail"),
	path('dep/update/<str:hashid>/', views.cLeaveDepUpdate, name="leave-dep-update"),
	path('dep/send/<str:hashid>/', views.cLeaveDepSend, name="leave-dep-send"),
	### Unit
	path('c/ver/list/', views.cLeaveVerList, name="leave-c-ver-list"),
	path('c/ver/detail/<str:hashid>/', views.cLeaveVerDetail, name="leave-c-ver-detail"),
	path('c/ver/update/<str:hashid>/', views.cLeaveVerUpdate, name="leave-c-ver-update"),
	path('c/ver/send/<str:hashid>/', views.cLeaveVerSend, name="leave-c-ver-send"),
	path('c/ver/reject/<str:hashid>/', views.cLeaveVerReject, name="leave-c-ver-reject"),
	path('c/send/<str:hashid>/', views.LeaveUnitSend, name="leave-unit-send"),
	path('c/done/<str:hashid>/', views.LeaveUnitDone, name="leave-unit-done"),
	#
	path('c/list/', views.cLeaveList, name="leave-c-list"),
	path('c/detail/<str:hashid>/', views.cLeaveDetail, name="leave-c-detail"),
	### HR
	path('hr/list/', views.hrLeaveList, name="leave-hr-list"),
	path('hr/config/list/', views.hrPeriodList, name="leave-hr-period-list"),
	path('hr/detail/<str:hashid>/', views.hrLeaveCertDetail, name="leave-hr-cert-detail"),
	path('hr/update/<str:hashid>/', views.hrLeaveCertUpdate, name="leave-hr-cert-update"),
	path('hr/send/<str:hashid>/', views.hrLeaveCertSend, name="leave-hr-cert-send"),
	#
	path('hr/leave/create/emp/period/<str:hashid>/', views.hrLeaveEmpPeriodAdd, name="leave-hr-leave-create-emp-record"),
	path('hr/leave/update/record/<str:hashid>/', views.hrLeaveUpdateEmpRecord, name="leave-hr-leave-update-emp-record"),
	path('hr/leave/record/<str:hashid>/', views.hrLeaveRecordPer, name="leave-hr-leave-record"),
	path('hr/leave/per/record/<str:hashid>/<int:pk>/', views.hrLeavePeriodRecordPer, name="leave-hr-leave-per-record"),
	path('hr/leave/update/record/month/<str:hashid>/', views.hrLeaveEmpUpdatePeriodMonth, name="leave-hr-leave-update-emp-record-month"),
	path('hr/leave/update/record/', views.hrLeaveUpdateRecord, name="leave-hr-leave-update-record"),
	path('hr/period/set/', views.hrLeavePeriodAdd, name="leave-hr-period-set"),
	path('hr/leave/list/', views.hrLeaveAppList, name="leave-hr-app-list"),
	path('hr/leave/raw/list/', views.hrLeaveAppRawList, name="leave-hr-app-raw-list"),
	path('hr/leave/add/<str:hashid>/', views.hrLeaveAdd, name="leave-hr-add"),
	path('hr/leave/add/spec/<str:hashid>/', views.hrLeaveAddSpecial, name="leave-hr-add-special"),
	path('hr/leave/add/proc/<str:hashid>/', views.hrLeaveAddProcess, name="leave-hr-add-process"),
	path('hr/app/detail/<str:hashid>/', views.hrLeaveAppDetail, name="leave-hr-app-detail"),
	path('hr/update/att/<str:hashid>/<str:hashid2>/', views.hrLeaveUpdateAtt, name="leave-hr-udpate-att"),
	path('hr/print/<str:hashid>/', views.hrLeavePrint, name="leave-hr-print"),
	path('hr/add/comment/<str:hashid>/', views.hrLeaveAddComment, name="leave-hr-add-comment"),
	path('hr/pdf/<str:hashid>/', views.hrLeavePDF, name="leave-hr-pdf"),
	path('hr/leave-send-process/<str:hashid>/<str:leave>/', views.hrLeaveSendProcess, name="leave-hr-send-process"),
	### DE
	path('pr/list/', views.deLeaveList, name="leave-de-list"),
	path('pr/detail/<str:hashid>/', views.deLeaveDetail, name="leave-de-detail"),
	path('pr/aprove/list/', views.deLeaveApprList, name="leave-de-appr-list"),
	path('pr/aprove/detail/<str:hashid>/', views.deLeaveApprDetail, name="leave-de-appr-detail"),
	path('pr/aprove/update/<str:hashid>/', views.deLeaveApprUpdate, name="leave-de-appr-update"),
	path('pr/aprove/finish/<str:hashid>/', views.deLeaveApprFinish, name="leave-de-appr-finish"),
	path('pr/notify/<str:hashid>/send/', views.prLeaveSendNotif, name="leave-de-notify-send"),
	path('pr/notify/rh/<str:hashid>/send/', views.prLeaveNotifyHR, name="leave-de-notify-hr"),
	###
	path('chart/dash/', views.LeaveChartDash, name="leave-chart-dash"),
	path('report/', include('leave.urls_report')),
]


# Generated by Django 3.2 on 2022-12-25 13:32

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0053_leavecount_total_taken'),
    ]

    operations = [
        migrations.AddField(
            model_name='leavecount',
            name='period',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='leaveperiodcount', to='leave.leaveperiod'),
        ),
        migrations.AlterField(
            model_name='leavecount',
            name='total',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=5, null=True, verbose_name='Total'),
        ),
    ]



# Generated by Django 4.0 on 2022-09-25 08:59

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0021_leave_is_approve_leave_is_reject'),
    ]

    operations = [
        migrations.RenameField(
            model_name='leave',
            old_name='s_is_finish',
            new_name='is_delegate',
        ),
        migrations.RenameField(
            model_name='leave',
            old_name='s_is_lock',
            new_name='is_lock',
        ),
        migrations.RenameField(
            model_name='leave',
            old_name='s_is_send',
            new_name='is_send',
        ),
    ]



from .leave_v import *
from .leave_m import *
from .leave_s_v import *
from .leave_s_m import *
from .leave_c_v import *
from .leave_c_m import *
from .leave_hr_v import *
from .leave_hr_m import *
from .leave_de_v import *
from .leave_de_m import *
from .print import *
from .leave_chart import *
from .leave_report import *


# Generated by Django 3.2 on 2023-03-13 14:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0072_auto_20230313_2331'),
    ]

    operations = [
        migrations.AlterField(
            model_name='leave',
            name='end_time_status',
            field=models.CharField(blank=True, choices=[('PM:12:00', 'PM:12:00'), ('PM:17:00', 'PM:17:00')], max_length=15, null=True, verbose_name='Horas Remata Licensa'),
        ),
        migrations.AlterField(
            model_name='leave',
            name='start_time_status',
            field=models.CharField(blank=True, choices=[('AM-08:00', 'AM-08:00'), ('PM:13:00', 'PM:13:00')], max_length=15, null=True, verbose_name='Horas Hahu Licensa'),
        ),
    ]



# Generated by Django 3.2 on 2023-01-18 02:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0061_leavecount_balance_month'),
    ]

    operations = [
        migrations.AddField(
            model_name='leavehr',
            name='comment',
            field=models.TextField(blank=True, null=True, verbose_name='Komentario'),
        ),
    ]



# Generated by Django 3.2 on 2022-12-17 07:14

import django.core.validators
from django.db import migrations, models
import settings_app.upload_utils


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0034_rename_pr_confirm_leave_pr_approve'),
    ]

    operations = [
        migrations.AddField(
            model_name='leave',
            name='file',
            field=models.FileField(blank=True, null=True, upload_to=settings_app.upload_utils.upload_leave, validators=[django.core.validators.FileExtensionValidator(allowed_extensions=['pdf'])], verbose_name='Upload Anekso'),
        ),
    ]



# Generated by Django 3.2 on 2022-12-20 08:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0045_auto_20221220_1722'),
    ]

    operations = [
        migrations.CreateModel(
            name='Month',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('code', models.IntegerField(blank=True, null=True)),
                ('name', models.CharField(blank=True, max_length=20, null=True)),
                ('is_active', models.BooleanField(default=False)),
            ],
        ),
        migrations.CreateModel(
            name='Year',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('year', models.IntegerField(blank=True, null=True)),
                ('is_active', models.BooleanField(default=False)),
            ],
        ),
    ]



# Generated by Django 3.2 on 2022-12-29 17:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0055_leave_description'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='leavecount',
            options={'ordering': ('pk', 'year')},
        ),
        migrations.AddField(
            model_name='leavecount',
            name='last_total_balance',
            field=models.DecimalField(blank=True, decimal_places=2, default=0.0, max_digits=5, null=True, verbose_name='Last Total Balance'),
        ),
    ]



# Generated by Django 4.0 on 2022-09-23 13:11

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0009_rename_is_lock_leave_s_is_finish_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='leave',
            name='de_obs',
            field=models.CharField(blank=True, choices=[('Sim', 'Sim'), ('Lae', 'Lae')], max_length=3, null=True, verbose_name='Observasaun'),
        ),
        migrations.AddField(
            model_name='leave',
            name='hr_obs',
            field=models.CharField(blank=True, choices=[('Sim', 'Sim'), ('Lae', 'Lae')], max_length=3, null=True, verbose_name='Observasaun'),
        ),
        migrations.AddField(
            model_name='leave',
            name='unit_obs',
            field=models.CharField(blank=True, choices=[('Sim', 'Sim'), ('Lae', 'Lae')], max_length=3, null=True, verbose_name='Observasaun'),
        ),
    ]



from django.shortcuts import render, get_object_or_404, redirect
from django.contrib.auth.decorators import login_required
from settings_app.decorators import allowed_users
from django.db.models import Sum, Count, Q
from leave.models import Leave, LeaveDE, LeaveDelegate, LeaveHR, LeaveUnit,LeaveCount,LeaveDep, LeavePeriod, LeaveType
from settings_app.user_utils import c_unit, c_staff
from employee.models import Employee
import pandas as pd
from django.contrib import messages
from contract.models import Contract
from datetime import datetime
import numpy as np
from leave.utils import check_period_date,check_period_range
from django.db.models import QuerySet
from django.template.loader import get_template
from django.http import FileResponse
import xhtml2pdf.pisa as pisa
from django.http import HttpResponse
import os
from django.conf import settings
from io import BytesIO
from settings_app.models import IPGInfo


@login_required
@allowed_users(allowed_roles=['admin','hr'])
def hrLeaveList(request):
	group = request.user.groups.all()[0].name
	c_emp = c_staff(request.user)
	objects = Leave.objects.filter(employee=c_emp).all().order_by('-start_date')
	period = LeavePeriod.objects.filter(employee=c_emp, is_active=True).last()
		
	context = {
		'group': group, 'objects': objects, 'period':period,
		'title': 'Lista Licensa', 'legend': 'Lista Licensa'
	}
	return render(request, 'leave/hr_cert_list.html', context)

@login_required
@allowed_users(allowed_roles=['admin','hr'])
def hrPeriodList(request):
	group = request.user.groups.all()[0].name
	c_emp = c_staff(request.user)
	year = datetime.now().year
	objects = LeavePeriod.objects.filter(is_active=True).order_by('-is_active')
	context = {
		'group': group, 'objects': objects, 'year': year,
		'title': 'Lista Periode', 'legend': 'Lista Periode'
	}
	return render(request, 'leave/hr_period_list.html', context)

@login_required
@allowed_users(allowed_roles=['admin','hr'])
def hrLeaveCertDetail(request, hashid):
	group = request.user.groups.all()[0].name
	leave = get_object_or_404(Leave, hashed=hashid)
	leavedel = LeaveDelegate.objects.filter(leave=leave).first()
	leaveunit = LeaveUnit.objects.filter(leave=leave).first()
	leavehr = LeaveHR.objects.filter(leave=leave).first()
	leavede = LeaveDE.objects.filter(leave=leave).first()
	context = {
		'group': group, 'leave': leave, 'leavedel': leavedel, 'leaveunit': leaveunit,
		'leavehr': leavehr, 'leavede': leavede,
		'title': 'Detalha Licensa', 'legend': 'Detalha Licensa'
	}
	return render(request, 'leave/hr_cert_detail.html', context)
###
@login_required
@allowed_users(allowed_roles=['admin','hr'])
def hrLeaveAppList(request):
	group = request.user.groups.all()[0].name
	objects = Leave.objects.all().order_by('-start_date')
	context = {
		'group': group, 'objects': objects,
		'title': 'Lista Pedido Licensa', 'legend': 'Lista Pedido Licensa'
	}
	return render(request, 'leave/hr_app_list.html', context)

# done: Leave Raw Data
@login_required
@allowed_users(allowed_roles=['admin','hr'])
def hrLeaveAppRawList(request):
	group = request.user.groups.all()[0].name
	objects = []
	employee = Employee.objects.filter(status_id=1)
	today = datetime.today().date()
	lc = None
	for i in employee:
		period = LeavePeriod.objects.filter(employee=i,is_active=True).last()
		periodcheck = LeavePeriod.objects.all().exists()
		leave = Leave.objects.filter(employee=i)
		alleavelast = LeaveCount.objects.filter(employee=i, period=period, leave_type_id=1, update_date__lt=today).last()
		alleavenext = LeaveCount.objects.filter(employee=i, period=period, leave_type_id=1, update_date__gt=today).first()
		ltabalance = LeaveCount.objects.filter(employee=i, leave_type_id=1, period__is_active=True).last()
		ltsbalance = LeaveCount.objects.filter(employee=i, leave_type_id=2, period__is_active=True).last()
		ltspbalance = LeaveCount.objects.filter(employee=i, leave_type_id=3, period__is_active=True).last()
		ltmbalance = LeaveCount.objects.filter(employee=i, leave_type_id=4, period__is_active=True).last()
		ltpbalance = LeaveCount.objects.filter(employee=i, leave_type_id=5, period__is_active=True).last()
		ltchbalance = LeaveCount.objects.filter(employee=i, leave_type_id=6, period__is_active=True).last()
		lc = LeaveCount.objects.filter(employee=i, period=period).exists()
		leavemonth = Leave.objects.filter(employee=i, leave_period=period, start_date__month=today.month, start_date__year=today.year,leave_type_id=1).exists()
		objects.append([i,leave, ltabalance, ltsbalance, ltspbalance, ltmbalance, ltpbalance, lc, ltchbalance,alleavelast,alleavenext,leavemonth])
		
	context = {
		'group': group, 'objects': objects,  'lc':lc, 'periodcheck':periodcheck,
		'title': 'Lista Raw Data Licenca', 'legend': 'Lista Raw Data Licenca', 'today':today
	}
	return render(request, 'leave/hr_raw_list.html', context)


# work: Work here
@login_required
@allowed_users(allowed_roles=['admin','hr'])
def hrLeaveRecordPer(request, hashid):
	group = request.user.groups.all()[0].name
	employee = get_object_or_404(Employee, hashed=hashid)
	contract = Contract.objects.filter(employee=employee, is_active=True).last()
	if contract:
		try:
			today = datetime.today().date()
			period  = get_object_or_404(LeavePeriod, employee=employee, is_active=True)
			leave = Leave.objects.filter(employee=employee, leave_period=period).order_by('-start_date')
			
			min_month = f'{period.start_year.year}-{period.start_month.code}-{period.start_date.day}'
			max_month = f'{today.year}-{today.month}-{period.start_date.day}'
			months = pd.date_range(min_month, max_month, freq='M')
			check_last_period = LeavePeriod.objects.filter(employee=employee,pk__lt=period.pk).last()
			all_period = LeavePeriod.objects.filter(employee=employee)
			last_count_period = LeaveCount.objects.filter(employee=employee, period=check_last_period, leave_type_id=1).last()
			lc = LeaveCount.objects.filter(employee=employee, period=period).exists()
			data = []
			data2 = []
			allmonth = check_period_range(period)
			for obj in allmonth:
				al = LeaveCount.objects.filter(employee=employee, period=period,  month__code=obj.month, year__year=obj.year, leave_type_id=1).last()
				sl = LeaveCount.objects.filter(employee=employee, period=period, month__code=obj.month, year__year=obj.year, leave_type_id=2).last()
				spl = LeaveCount.objects.filter(employee=employee, period=period, month__code=obj.month, year__year=obj.year, leave_type_id=3).last()
				mtl = LeaveCount.objects.filter(employee=employee, period=period,month__code=obj.month, year__year=obj.year, leave_type_id=4).last()
				ptl = LeaveCount.objects.filter(employee=employee, period=period,month__code=obj.month, year__year=obj.year, leave_type_id=5).last()
				cl = LeaveCount.objects.filter(employee=employee, period=period,month__code=obj.month, year__year=obj.year, leave_type_id=6).last()
				lmonth = Leave.objects.filter(employee=employee, leave_period=period, start_date__month=obj.month, start_date__year=obj.year,leave_type_id=1).exists()

				data2.append([obj, al,sl, spl, mtl, ptl, cl, lmonth])
			objects = []
			alleave = LeaveCount.objects.filter(employee=employee, period=period, leave_type_id=1).last()
			alleavelast = LeaveCount.objects.filter(employee=employee, period=period, leave_type_id=1, update_date__lt=today).last()
			alleavenext = LeaveCount.objects.filter(employee=employee, period=period, leave_type_id=1, update_date__gt=today).first()
			alleavethis = LeaveCount.objects.filter(employee=employee, period=period, leave_type_id=1, update_date__month=today.month, update_date__year=today.year).last()

			sickleave = LeaveCount.objects.filter(employee=employee, period=period, leave_type_id=2).all().order_by('pk')
			spleave = LeaveCount.objects.filter(employee=employee, period=period, leave_type_id=3).all().order_by('pk')
			mtleave = LeaveCount.objects.filter(employee=employee, period=period, leave_type_id=4).all().order_by('pk')
			ptleave = LeaveCount.objects.filter(employee=employee, period=period, leave_type_id=5).all().order_by('pk')
			chleave = LeaveCount.objects.filter(employee=employee, period=period, leave_type_id=6).all().order_by('pk')
			leavecheck = LeaveCount.objects.filter(employee=employee, period=period, period__employee=employee ).exists()
			leavemonth = Leave.objects.filter(employee=employee, leave_period=period, start_date__month=today.month, start_date__year=today.year,leave_type_id=1).exists()
			objects.append([alleave, spleave,sickleave, mtleave, ptleave,chleave, data, leavemonth, alleavelast,alleavenext, alleavethis])

			check_date = check_period_date(period.start_date)
			check_last_month_per = LeaveCount.objects.filter(employee=employee, period=period, leave_type_id=1,  month__code=1, year__year=2023).exists()

			context = {
				'group': group, 'employee':employee, 'alleave':alleave, 'period':period, 'leave':leave, 'last_count_period':last_count_period, 'today':check_date,
				'title': 'Leave Record', 'legend': 'Leave Record', 'objects': objects, 'leavecheck':leavecheck, 'all_period':all_period, 'contract':contract, \
				'check_last_month_per':check_last_month_per, 'today':today,'allmonth':allmonth, 'data':data2, 'today':today, 'lc':lc
			}
			return render(request, 'leave/hr_leave_record.html', context)				
		except:
			if contract.start_date:
				context = {
					'legend': 'Leave Record', 'employee':employee, 'contract': contract
				}
				return render(request, 'leave/hr_leave_record.html', context)				
			else:
				messages.error(request, 'Contrato seidauk kria!!')
				return redirect('leave-hr-app-raw-list')	
	else:
		messages.error(request, f'Funsionario {employee} nia Kontrato seidauk kria!!')
		return redirect('leave-hr-app-raw-list')	

	

# work: Work here
@login_required
@allowed_users(allowed_roles=['admin','hr'])
def hrLeavePeriodRecordPer(request, hashid, pk):
	group = request.user.groups.all()[0].name
	employee = get_object_or_404(Employee, hashed=hashid)
	period  = get_object_or_404(LeavePeriod, pk=pk)
	today = datetime.today().date()
	contract = Contract.objects.filter(employee=employee, is_active=True).last()
	leave = Leave.objects.filter(employee=employee, leave_period=period).order_by('-start_date')
	min_month = f'{period.start_year.year}-{period.start_month.code}-{period.start_date.day}'
	max_month = f'{today.year}-{today.month}-{period.start_date.day}'
	months = pd.date_range(min_month, max_month, freq='M')
	check_last_period = LeavePeriod.objects.filter(employee=employee,pk__lt=period.pk).last()
	all_period = LeavePeriod.objects.filter(employee=employee)
	last_count_period = LeaveCount.objects.filter(employee=employee, period=check_last_period, leave_type_id=1).last()
	lc = LeaveCount.objects.filter(employee=employee, period=period).exists()
	data = []
	data2 = []
	allmonth = check_period_range(period)
	for obj in allmonth:
		al = LeaveCount.objects.filter(employee=employee, period=period,  month__code=obj.month, year__year=obj.year, leave_type_id=1).last()
		sl = LeaveCount.objects.filter(employee=employee, period=period, month__code=obj.month, year__year=obj.year, leave_type_id=2).last()
		spl = LeaveCount.objects.filter(employee=employee, period=period, month__code=obj.month, year__year=obj.year, leave_type_id=3).last()
		mtl = LeaveCount.objects.filter(employee=employee, period=period,month__code=obj.month, year__year=obj.year, leave_type_id=4).last()
		ptl = LeaveCount.objects.filter(employee=employee, period=period,month__code=obj.month, year__year=obj.year, leave_type_id=5).last()
		cl = LeaveCount.objects.filter(employee=employee, period=period,month__code=obj.month, year__year=obj.year, leave_type_id=6).last()
		lmonth = Leave.objects.filter(employee=employee, leave_period=period, start_date__month=obj.month, start_date__year=obj.year,leave_type_id=1).exists()

		data2.append([obj, al,sl, spl, mtl, ptl, cl, lmonth])
	objects = []
	alleave = LeaveCount.objects.filter(employee=employee, period=period, leave_type_id=1).last()
	alleavelast = LeaveCount.objects.filter(employee=employee, period=period, leave_type_id=1, update_date__lt=today).last()
	alleavenext = LeaveCount.objects.filter(employee=employee, period=period, leave_type_id=1, update_date__gt=today).first()
	alleavethis = LeaveCount.objects.filter(employee=employee, period=period, leave_type_id=1, update_date__month=today.month, update_date__year=today.year).last()

	sickleave = LeaveCount.objects.filter(employee=employee, period=period, leave_type_id=2).all().order_by('pk')
	spleave = LeaveCount.objects.filter(employee=employee, period=period, leave_type_id=3).all().order_by('pk')
	mtleave = LeaveCount.objects.filter(employee=employee, period=period, leave_type_id=4).all().order_by('pk')
	ptleave = LeaveCount.objects.filter(employee=employee, period=period, leave_type_id=5).all().order_by('pk')
	chleave = LeaveCount.objects.filter(employee=employee, period=period, leave_type_id=6).all().order_by('pk')
	leavecheck = LeaveCount.objects.filter(employee=employee, period=period, period__employee=employee ).exists()
	leavemonth = Leave.objects.filter(employee=employee, leave_period=period, start_date__month=today.month, start_date__year=today.year,leave_type_id=1).exists()
	objects.append([alleave, spleave,sickleave, mtleave, ptleave,chleave, data, leavemonth, alleavelast,alleavenext, alleavethis])

	check_date = check_period_date(period.start_date)
	check_last_month_per = LeaveCount.objects.filter(employee=employee, period=period, leave_type_id=1,  month__code=1, year__year=2023).exists()
		
	context = {
			'group': group, 'employee':employee, 'alleave':alleave, 'period':period, 'leave':leave, 'last_count_period':last_count_period, 'today':check_date,
			'title': 'Leave Record', 'legend': 'Leave Record', 'objects': objects, 'leavecheck':leavecheck, 'all_period':all_period, 'contract':contract, \
			'check_last_month_per':check_last_month_per, 'today':today,'allmonth':allmonth, 'data':data2, 'today':today, 'lc':lc, 'page': 'list-year'
	}
	return render(request, 'leave/hr_leave_record.html', context)




@login_required
@allowed_users(allowed_roles=['admin','hr'])
def hrLeaveAppDetail(request, hashid):
	group = request.user.groups.all()[0].name
	leave = get_object_or_404(Leave, hashed=hashid)
	emp_unit = c_unit(leave.employee.employeeuser.user)
	cgroup = leave.user.groups.all()[0].name
	leavedel = LeaveDelegate.objects.filter(leave=leave).first()
	leavedep = LeaveDep.objects.filter(leave=leave).first()
	leaveunit = LeaveUnit.objects.filter(leave=leave).first()
	leavehr = LeaveHR.objects.filter(leave=leave).first()
	leavede = LeaveDE.objects.filter(leave=leave).first()
	context = {
		'group': group, 'leave': leave, 'leavedel': leavedel, 'leaveunit': leaveunit,
		'leavehr': leavehr, 'leavede': leavede, 'leavedep':leavedep, 'emp_unit':emp_unit,
		'title': 'Detalha Licensa', 'legend': 'Detalha Licensa', 'cgroup':cgroup
	}
	return render(request, 'leave/hr_app_detail.html', context)

import os

def get_image_path(image_name):
    current_dir = os.path.dirname(os.path.abspath(__file__))
    image_path = os.path.join(current_dir, 'main', 'static', 'main', 'images', image_name)
    return image_path


@login_required
@allowed_users(allowed_roles=['admin','hr'])
def hrLeavePDF(request, hashid):
	group = request.user.groups.all()[0].name
	leave = get_object_or_404(Leave, hashed=hashid)
	cgroup = leave.user.groups.all()[0].name
	leavedep = LeaveDep.objects.filter(leave=leave).first()
	leaveunit = LeaveUnit.objects.filter(leave=leave).first()
	leavehr = LeaveHR.objects.filter(leave=leave).first()
	leavede = LeaveDE.objects.filter(leave=leave).first()
	ipginfo = IPGInfo.objects.filter(is_active=True).last()
	response = HttpResponse(content_type='application/pdf')
	response['Content-Disposition'] = 'inline; filename="mypdf.pdf"'
	template = get_template('pdf/leave.html')
	host_url = request.get_host()
	path = f'{host_url}/media/{ipginfo.cop}'
	context = {
		'mpm_path': 'main/static/main/images/mpm.png',
		'ipg_path': 'https://'+path,
		'title': 'PDF Licensa', 'cgroup':cgroup, 
		'leavedep':leavedep, 'leaveunit':leaveunit, 'leavehr':leavehr,
		'leavede':leavede, 'leave':leave, 'ipginfo':ipginfo
	}
	html = template.render(context)

	pisaStatus = pisa.CreatePDF(html, dest=response)

	return response

def fetch_resources(uri, rel):
    path = os.path.join(settings.MEDIA_ROOT, uri.replace(settings.MEDIA_URL, ""))
    return path


# Generated by Django 3.2 on 2023-01-10 05:27

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('employee', '0019_employee_ext'),
        ('leave', '0057_alter_leavecount_options'),
    ]

    operations = [
        migrations.AddField(
            model_name='leaveperiod',
            name='employee',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='leaveperiod', to='employee.employee'),
        ),
    ]



# Generated by Django 3.2 on 2022-12-25 12:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0051_alter_leavecount_taken'),
    ]

    operations = [
        migrations.AddField(
            model_name='leavecount',
            name='prov_total_earn',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=5, null=True, verbose_name='Provision Total Earn'),
        ),
    ]



import datetime
from django.shortcuts import render, redirect, get_object_or_404
from django.contrib.auth.decorators import login_required
from settings_app.decorators import allowed_users
from django.contrib import messages
from employee.models import CurEmpDivision, Employee
from leave.models import Leave, LeaveHR, LeaveUnit, LeaveCount, LeavePeriod, Month as Mnth, Year as Yr, LeaveType
from leave.forms import LeaveHRForm, LeaveUnitForm, LeaveForm, HRLeaveForm, HRPeriodForm, HRLeaveCommentForm
from settings_app.utils import getnewid, f_monthname
from settings_app.user_utils import c_staff, c_unit
from dateutil.parser import parser
from datetime import datetime as dt, timedelta
from attendance.models import Attendance, AttendanceStatus,Year, Month
import pytz
import pandas as pd
from django.db.models import Q, F
from django.utils import timezone
from calendar import mdays
from attendance.models import Attendance, AttendanceStatus, Year as YAten, Month as Maten
from leave.utils import createAttendance, createLeave, check_day
from contract.models import Contract
import calendar
from django.utils.safestring import mark_safe
from custom.models import Unit
import numpy as np
from leave.forms import LeaveFilterForm

def get_years():
    current_year = datetime.datetime.now().year
    return [year for year in range(2012, current_year + 1)]

@login_required
@allowed_users(allowed_roles=['admin','hr'])
def hrLeaveReportDash(request):
    form = LeaveFilterForm(request.GET or None)
    years = get_years()
    months = Mnth.objects.all()
    units = Unit.objects.all()
    trimestral = np.array([[1,'Trimestre I','01','04'],[2,'Trimestre II','04','07'],\
				[3,'Trimestre III','07','10'],[4,'Trimestre IV','10','13']])
    leave_type = LeaveType.objects.all()
    if request.method == 'GET':
        tinan = dt.now().year
        if request.GET.get('tinan') != 0:
            tinan = request.GET.get('tinan')
        else:
            tinan = dt.now().year
        tri = request.GET.get('tri')
        fulan = request.GET.get('fulan')
        unit = request.GET.get('unit')
        filtered_leaves = Leave.objects.all()
        allleave = None
        legend = 'Painel Relatior Licensa'
        title = 'Painel Relatior Licensa'
        data = []

        if tinan or tinan and unit:
            filtered_leaves = filtered_leaves.filter(start_date__year=tinan, hr_confirm=True, is_done=True).count()
            allleave = Leave.objects.filter(start_date__year=tinan, is_active=True,employee__curempdivision__unit_id=unit, hr_confirm=True, is_done=True).count()
            for i in leave_type:
                cleave = Leave.objects.filter(leave_type=i,start_date__year=tinan, is_active=True,employee__curempdivision__unit_id=unit, hr_confirm=True, is_done=True).count()
                data.append([i, cleave])
            legend = f'Relatorio Licensa iha Tinan <span class="text-danger"> {tinan} </span>'

        
        context=  {
            'title': legend,'legend': legend, 'data': data,'allleave':allleave,
            'years':years,'trimestral':trimestral, 'months':months, 'units':units, 'year':tinan
        }

        
        return render(request, 'leave_report/dash.html', context)
    context = {
        'title': 'Relatorio Licensa', 'legend': 'Relatorio Licensa',
        'years':years, 'trimestral':trimestral, 'months':months, 'units':units
    }
        
    return render(request, 'leave_report/dash.html', context)



@login_required
@allowed_users(allowed_roles=['admin','hr'])
def hrLeaveReportDash(request):
    years = get_years()
    months = Mnth.objects.all()
    leave_type = LeaveType.objects.all()
    units = Unit.objects.all()
    tyear = dt.now().year
    data = []
    year_get, month = 0,0
    allleave = None
    error = None
    legend = None
    get_year, get_month, get_tri, get_unit, page = None, None, None, None, None
    trimestral = np.array([[1,'Trimestre I','01','04'],[2,'Trimestre II','04','07'],\
				[3,'Trimestre III','07','10'],[4,'Trimestre IV','10','13']])
    getYear = request.POST.get('tinan')
    getMonth = request.POST.get('fulan')
    getUnit = request.POST.get('unit')
    getTri = request.POST.get('tri')
    datamonth = []

    if request.method == 'POST':

        if getTri != '0' and getMonth != '0':
            legend ='Deskulpa, Fulan No Trimestral labele hili hamutuk'
            error = messages.error(request,'Deskulpa, Fulan No Trimestral labele hili hamutuk')
        # done: DONE
        elif getYear != '0'  and getTri != '0' and getUnit != '0':
            tri = int(getTri)
            tri = int(tri)-1
            tris = trimestral[tri]
            allleave = Leave.objects.filter(start_date__year=int(getYear), start_date__month__gte=tris[2],  start_date__month__lte=tris[3], employee__curempdivision__unit_id=int(getUnit), is_active=True, hr_confirm=True, is_done=True).count()
            for i in leave_type:
                cleave = Leave.objects.filter(leave_type=i,start_date__year=int(getYear), start_date__month__gte=tris[2],  start_date__month__lte=tris[3], employee__curempdivision__unit_id=int(getUnit), hr_confirm=True, is_done=True).count()
                data.append([i, cleave])
            unit_name = get_object_or_404(Unit, pk=int(getUnit))
            legend = f'Relatorio Licensa iha Tinan <span class="text-danger"> {int(int(getYear))} </span>,   <span class="text-danger"> {tris[1]} </span>, Divizaun  <span class="text-danger"> {unit_name.name} </span>'
            get_year = int(getYear)
            get_tri = int(getTri)
            get_unit = int(getUnit)
            page = 'year-tri-unit'
        # done: DONE
        elif getYear!= '0' and getMonth!= '0' and getUnit!= '0':
            monthname = f_monthname(int(getMonth))
            allleave = Leave.objects.filter(start_date__year=int(getYear),start_date__month=int(getMonth),employee__curempdivision__unit_id=int(getUnit),  hr_confirm=True, is_done=True).count()
            for i in leave_type:
                cleave = Leave.objects.filter(start_date__year=int(getYear),start_date__month=int(getMonth),leave_type=i,employee__curempdivision__unit_id=int(getUnit),  hr_confirm=True, is_done=True).count()
                data.append([i, cleave])
            unit_name = get_object_or_404(Unit, pk=int(getUnit))
            start_date = dt(int(getYear), int(getMonth), 1)
            end_date = dt(int(getYear), int(getMonth), calendar.monthrange(int(getYear), int(getMonth))[1])
            delta = timedelta(days=1)
            while start_date <= end_date:
                alleave = Leave.objects.filter(start_date=start_date.date(),employee__curempdivision__unit_id=int(getUnit), hr_confirm=True, is_done=True).count()
                datamonth.append([start_date, alleave])
                start_date += delta
            legend = f'Relatorio Licensa iha Tinan <span class="text-danger"> {int(getYear)} </span>, Fulan  <span class="text-danger"> {monthname} </span>,  Divizaun  <span class="text-danger"> {unit_name.name} </span>'
            get_year = int(getYear)
            get_month = int(getMonth)
            get_unit = int(getUnit)
            page = 'year-month-unit'
        # done: DONE
        elif getYear != '0' and getTri != '0' :
            tri = int(getTri)
            tri = int(tri)-1
            tris = trimestral[tri]
            allleave = Leave.objects.filter(start_date__year=getYear, start_date__month__gte=tris[2],  start_date__month__lte=tris[3],  is_active=True, hr_confirm=True, is_done=True).count()
            for i in leave_type:
                cleave = Leave.objects.filter(leave_type=i,start_date__year=getYear, start_date__month__gte=tris[2],  start_date__month__lte=tris[3], hr_confirm=True, is_done=True).count()
                data.append([i, cleave])
            legend = f'Relatorio Licensa iha Tinan <span class="text-danger"> {int(getYear)} </span>,   <span class="text-danger"> {tris[1]} </span>'
            get_year = int(getYear)
            get_tri = int(getTri)
            page = 'year-tri'
        # done: DONE
        elif getMonth != '0' and getUnit != '0' :
            monthname = f_monthname(int(getMonth))
            allleave = Leave.objects.filter(start_date__year=int(tyear),start_date__month=int(getMonth),employee__curempdivision__unit_id=int(getUnit),  hr_confirm=True, is_done=True).count()
            for i in leave_type:
                cleave = Leave.objects.filter(start_date__year=int(tyear),start_date__month=int(getMonth),leave_type=i,employee__curempdivision__unit_id=int(getUnit),  hr_confirm=True, is_done=True).count()
                data.append([i, cleave])
            unit_name = get_object_or_404(Unit, pk=int(getUnit))
            start_date = dt(tyear, int(getMonth), 1)
            end_date = dt(tyear, int(getMonth), calendar.monthrange(tyear, int(getMonth))[1])
            delta = timedelta(days=1)
            while start_date <= end_date:
                alleave = Leave.objects.filter(start_date=start_date.date(),employee__curempdivision__unit_id=int(getUnit), hr_confirm=True, is_done=True).count()
                datamonth.append([start_date, alleave])
                start_date += delta
            legend = f'Relatorio Licensa iha Tinan <span class="text-danger"> {int(tyear)} </span>, Fulan  <span class="text-danger"> {monthname} </span>,  Divizaun  <span class="text-danger"> {unit_name.name} </span>'
            get_month = int(getMonth)
            get_unit = int(getUnit)
            page = 'month-unit'
        # done: DONE
        elif getYear != '0' and getMonth != '0' :
            monthname = f_monthname(int(getMonth))
            allleave = Leave.objects.filter(start_date__year=int(getYear),start_date__month=int(getMonth), hr_confirm=True, is_done=True).count()
            for i in leave_type:
                cleave = Leave.objects.filter(leave_type=i,start_date__year=int(getYear), start_date__month=int(getMonth),  hr_confirm=True, is_done=True).count()
                data.append([i, cleave])
            start_date = dt(int(getYear), int(getMonth), 1)
            end_date = dt(int(getYear), int(getMonth), calendar.monthrange(int(getYear), int(getMonth))[1])
            delta = timedelta(days=1)
            while start_date <= end_date:
                alleave = Leave.objects.filter(start_date=start_date.date(), hr_confirm=True, is_done=True).count()
                datamonth.append([start_date, alleave])
                start_date += delta
            legend = f'Relatorio Licensa iha Tinan <span class="text-danger"> {int(getYear)} </span> fulan <span class="text-danger"> {monthname} </span> '
            get_year = int(getYear)
            get_month = int(getMonth)
            page = 'year-month'
        # done: DONE
        elif getYear != '0' and getUnit != '0' :
            allleave = Leave.objects.filter(start_date__year=int(getYear),employee__curempdivision__unit_id=int(getUnit),  hr_confirm=True, is_done=True).count()
            for i in leave_type:
                cleave = Leave.objects.filter(start_date__year=int(getYear),leave_type=i,employee__curempdivision__unit_id=int(getUnit),  hr_confirm=True, is_done=True).count()
                data.append([i, cleave])
            unit_name = get_object_or_404(Unit, pk=int(getUnit))
            legend = f'Relatorio Licensa iha Tinan <span class="text-danger"> {int(getYear)} </span>,  Divizaun  <span class="text-danger"> {unit_name.name} </span>'
            get_year = int(getYear)
            get_unit = int(getUnit)
            page = 'year-unit'
        # done: DONE
        elif getMonth != '0':
            monthname = f_monthname(int(getMonth))
            allleave = Leave.objects.filter(start_date__year=tyear,start_date__month=int(getMonth), hr_confirm=True, is_done=True).count()
            for i in leave_type:
                cleave = Leave.objects.filter(leave_type=i,start_date__year=tyear, start_date__month=int(getMonth),  hr_confirm=True, is_done=True).count()
                data.append([i, cleave])
            start_date = dt(tyear, int(getMonth), 1)
            end_date = dt(tyear, int(getMonth), calendar.monthrange(tyear, int(getMonth))[1])
            delta = timedelta(days=1)
            while start_date <= end_date:
                alleave = Leave.objects.filter(start_date=start_date.date(), hr_confirm=True, is_done=True).count()
                datamonth.append([start_date, alleave])
                start_date += delta
            legend = f'Relatorio Licensa iha Tinan <span class="text-danger"> {tyear} </span> fulan <span class="text-danger"> {monthname} </span> '
            get_month = int(getMonth)
            page = 'month'

        # done: DONE
        elif getTri != '0':
            tri = int(getTri)
            tri = int(tri)-1
            tris = trimestral[tri]
            allleave = Leave.objects.filter(start_date__year=tyear, start_date__month__gte=tris[2],  start_date__month__lte=tris[3], hr_confirm=True, is_done=True).count()
            for i in leave_type:
                cleave = Leave.objects.filter(leave_type=i,start_date__year=tyear, start_date__month__gte=tris[2],  start_date__month__lte=tris[3], hr_confirm=True, is_done=True).count()
                data.append([i, cleave])
            legend = f'Relatorio Licensa iha Tinan <span class="text-danger"> {int(tyear)} </span>,   <span class="text-danger"> {tris[1]} </span>'
            get_tri = int(getTri)
            page = 'tri'

        # done: DONE
        elif getUnit != '0':
            allleave = Leave.objects.filter(employee__curempdivision__unit_id=int(getUnit),  hr_confirm=True, is_done=True).count()
            for i in leave_type:
                cleave = Leave.objects.filter(leave_type=i,employee__curempdivision__unit_id=int(getUnit),  hr_confirm=True, is_done=True).count()
                data.append([i, cleave])
            unit_name = get_object_or_404(Unit, pk=int(getUnit))
            legend = f'Relatorio Licensa husi Divizaun  <span class="text-danger"> {unit_name.name} </span>'
            get_unit = int(getUnit)
            page = 'unit'
        # done: DONE
        elif getYear != '0':
            allleave = Leave.objects.filter(start_date__year=int(getYear), hr_confirm=True, is_done=True).count()
            for i in leave_type:
                cleave = Leave.objects.filter(leave_type=i,start_date__year=int(getYear), hr_confirm=True, is_done=True).count()
                data.append([i, cleave])
            legend = f'Relatorio Licensa iha Tinan <span class="text-danger"> {int(getYear)} </span>'
            get_year = int(getYear)
            page = 'year'
        else:
            allleave = Leave.objects.filter(start_date__year=int(tyear), hr_confirm=True, is_done=True).count()
            for i in leave_type:
                cleave = Leave.objects.filter(leave_type=i,start_date__year=int(tyear), hr_confirm=True, is_done=True).count()
                data.append([i, cleave])
            legend = f'Relatorio Licensa iha Tinan <span class="text-danger"> {int(tyear)} </span>'
            get_year = int(tyear)
            page = 'year'

    else:      
        allleave = Leave.objects.filter(start_date__year=int(tyear), hr_confirm=True, is_done=True).count()
        for i in leave_type:
            cleave = Leave.objects.filter(leave_type=i,start_date__year=tyear, hr_confirm=True, is_done=True).count()
            data.append([i, cleave])
        legend = f'Painel Relatorio Licensa iha Tinan <span class="text-danger"> {tyear} </span>'
    
    context = {
        'title': 'Painel Relatorio Licensa','legend': legend, 
        'years': years, 'months': months, 'data': data, 'allleave':allleave, 'year': tyear, 'units':units,
        'trimestral':trimestral, 'error': error, 'page': page, 'datamonth':datamonth,
        'get_year': get_year, 'get_month': get_month, 'get_tri': get_tri, 'get_unit': get_unit,
    }
    return render(request, 'leave_report/dash.html', context)


@login_required
@allowed_users(allowed_roles=['admin','hr'])
def hrLeaveReportLeaveTypeList(request, pk, year):
    lt = get_object_or_404(LeaveType, pk=pk)
    allleave = None
    objects = Leave.objects.filter(leave_type=lt,start_date__year=year, is_active=True, hr_confirm=True, is_done=True)


    context = {
        'title': 'Lista Licensa','legend': f'Lista Licensa iha Tinan {year}', 
        'objects': objects, 'allleave':allleave, 'year': year
    }
    return render(request, 'leave_report/list.html', context)

@login_required
@allowed_users(allowed_roles=['admin','hr'])
def hrLeaveReportLeaveTypeListAll(request, year):
    objects = Leave.objects.filter(start_date__year=year, is_active=True, hr_confirm=True, is_done=True)
    context = {
        'title': 'Lista Licensa','legend': f'Lista Licensa iha Tinan {year}', 
        'objects': objects, 'year': year
    }
    return render(request, 'leave_report/list.html', context)


@login_required
@allowed_users(allowed_roles=['admin','hr'])
def hrLeaveReportLeaveMonthTypeList(request, date):
    objects = Leave.objects.filter(start_date=date,hr_confirm=True, is_done=True)
    date_object = dt.strptime(date, "%Y-%m-%d")
    monthname = f_monthname(int(date_object.month))
    context = {
        'objects': objects,  'date':date,
        'title': 'Lista Licensa','legend': f'Lista Licensa iha loron {date_object.day}-{monthname}-{date_object.year}', 
    }
    return render(request, 'leave_report/list_day.html', context)


# REPORT DETAIL
# work: YEAR
@login_required
@allowed_users(allowed_roles=['admin','hr'])
def hrReportLeaveYear(request,pk, year):
    lt = get_object_or_404(LeaveType, pk=pk)
    objects = Leave.objects.filter(leave_type=lt,start_date__year=year, is_active=True, hr_confirm=True, is_done=True)
    context = {
        'title': 'Lista Licensa','legend': f'Lista Licensa {lt.name} iha Tinan {year}', 
        'objects': objects, 'year': year
    }
    return render(request, 'leave_report/list.html', context)

@login_required
@allowed_users(allowed_roles=['admin','hr'])
def hrReportLeaveYearAll(request, year):
    objects = Leave.objects.filter(start_date__year=year, is_active=True, hr_confirm=True, is_done=True)
    context = {
        'title': 'Lista Licensa','legend': f'Lista Licensa iha Tinan {year}', 
        'objects': objects, 'year': year
    }
    return render(request, 'leave_report/list.html', context)

# work: UNIT
@login_required
@allowed_users(allowed_roles=['admin','hr'])
def hrReportLeaveUnit(request,pk, pk2):
    lt = get_object_or_404(LeaveType, pk=pk)
    unit = get_object_or_404(Unit, pk=pk2)
    objects = Leave.objects.filter(leave_type=lt,employee__curempdivision__unit=unit,  hr_confirm=True, is_done=True)
    context = {
        'title': 'Lista Licensa','legend': f'Lista Licensa {lt.name} iha Divizaun {unit.name}', 
        'objects': objects, 
    }
    return render(request, 'leave_report/list.html', context)

@login_required
@allowed_users(allowed_roles=['adhrReportLeaveUnitmin','hr'])
def hrReportLeaveUnitAll(request,pk):
    unit = get_object_or_404(Unit, pk=pk)
    objects = Leave.objects.filter(employee__curempdivision__unit=unit,  hr_confirm=True, is_done=True)
    context = {
        'title': 'Lista Licensa','legend': f'Lista Licensa iha Divizaun {unit.name}', 
        'objects': objects
    }
    return render(request, 'leave_report/list.html', context)

# work: TRIMESTRAL
@login_required
@allowed_users(allowed_roles=['admin','hr'])
def hrReportLeaveTri(request,pk, pk2):
    lt = get_object_or_404(LeaveType, pk=pk)
    trimestral = np.array([[1,'Trimestre I','01','04'],[2,'Trimestre II','04','07'],\
				[3,'Trimestre III','07','10'],[4,'Trimestre IV','10','13']])
    tri = int(pk2)-1
    tris = trimestral[tri]
    tyear = dt.now().year
    objects = Leave.objects.filter(leave_type=lt,start_date__year=tyear, start_date__month__gte=tris[2],  start_date__month__lte=tris[3], hr_confirm=True, is_done=True)
    context = {
        'title': 'Lista Licensa','legend': f'Lista Licensa {lt.name}, Tinan, {tyear}, {tris[1]}', 
        'objects': objects, 
    }
    return render(request, 'leave_report/list.html', context)

@login_required
@allowed_users(allowed_roles=['adhrReportLeaveUnitmin','hr'])
def hrReportLeaveTriAll(request):
    tyear = dt.now().year
    data = []
    trimestral = np.array([[1,'Trimestre I','01','04'],[2,'Trimestre II','04','07'],\
				[3,'Trimestre III','07','10'],[4,'Trimestre IV','10','13']])
    for tris in trimestral:
        objects = Leave.objects.filter(start_date__year=tyear, start_date__month__gte=tris[2],  start_date__month__lte=tris[3], hr_confirm=True, is_done=True)
        for i in objects:
            if i:
                data.append(i)
    context = {
        'title': 'Lista Licensa','legend': f'Lista Licensa Trimestral, Tinan {tyear}', 
        'objects': data
    }
    return render(request, 'leave_report/list.html', context)


# work: MONTH
@login_required
@allowed_users(allowed_roles=['admin','hr'])
def hrReportLeaveMonth(request, pk, month):
    tyear = dt.now().year
    monthname = f_monthname(int(month))
    lt = get_object_or_404(LeaveType, pk=pk)
    objects = Leave.objects.filter(leave_type=lt,start_date__year=tyear,start_date__month=month, is_active=True, hr_confirm=True, is_done=True)
    context = {
        'title': 'Lista Licensa','legend': f'Lista Licensa Tinan {tyear} Fulan {monthname}', 
        'objects': objects,
    }
    return render(request, 'leave_report/list.html', context)

@login_required
@allowed_users(allowed_roles=['admin','hr'])
def hrReportLeaveMonthAll(request, month):
    tyear = dt.now().year
    monthname = f_monthname(int(month))
    objects = Leave.objects.filter(start_date__year=tyear,start_date__month=month, hr_confirm=True, is_done=True)
    context = {
        'title': 'Lista Licensa','legend': f'Lista Licensa iha Tinan {tyear}, Fulan {monthname}', 
        'objects': objects
    }
    return render(request, 'leave_report/list.html', context)


# work: YEAR UNIT
@login_required
@allowed_users(allowed_roles=['admin','hr'])
def hrReportLeaveYearUnit(request, pk,pk2, year):
    lt = get_object_or_404(LeaveType, pk=pk)
    unit = get_object_or_404(Unit, pk=pk2)
    objects = Leave.objects.filter(start_date__year=int(year),leave_type=lt,employee__curempdivision__unit_id=int(pk2),  hr_confirm=True, is_done=True)
    context = {
        'title': 'Lista Licensa','legend': f'Lista Licensa  {lt.name}, Tinan {year}, Divizaun {unit.name}', 
        'objects': objects, 'year': year
    }
    return render(request, 'leave_report/list.html', context)

@login_required
@allowed_users(allowed_roles=['admin','hr'])
def hrReportLeaveYearUnitAll(request,pk, year):
    unit = get_object_or_404(Unit, pk=pk)
    objects = Leave.objects.filter(start_date__year=int(year),employee__curempdivision__unit_id=int(pk),  hr_confirm=True, is_done=True)
    context = {
        'title': 'Lista Licensa','legend': f'Lista Licensa Tinan {year}, Divizaun {unit.name}', 
        'objects': objects, 'year': year
    }
    return render(request, 'leave_report/list.html', context)


# work: YEAR MONTH
@login_required
@allowed_users(allowed_roles=['admin','hr'])
def hrReportLeaveMonth(request, pk,year, month):
    monthname = f_monthname(int(month))
    lt = get_object_or_404(LeaveType, pk=pk)
    objects = Leave.objects.filter(leave_type=lt,start_date__year=year,start_date__month=month, is_active=True, hr_confirm=True, is_done=True)
    context = {
        'title': 'Lista Licensa','legend': f'Lista Licensa Tinan {year} Fulan {monthname}', 
        'objects': objects,
    }
    return render(request, 'leave_report/list.html', context)

@login_required
@allowed_users(allowed_roles=['admin','hr'])
def hrReportLeaveMonthAll(request,year, month):
    monthname = f_monthname(int(month))
    objects = Leave.objects.filter(start_date__year=year,start_date__month=month, hr_confirm=True, is_done=True)
    context = {
        'title': 'Lista Licensa','legend': f'Lista Licensa iha Tinan {year}, Fulan {monthname}', 
        'objects': objects
    }
    return render(request, 'leave_report/list.html', context)

# work: MONTH UNIT
@login_required
@allowed_users(allowed_roles=['admin','hr'])
def hrReportLeaveMonthUnit(request, pk, month, unit):
    tyear = dt.now().year
    monthname = f_monthname(int(month))
    lt = get_object_or_404(LeaveType, pk=pk)
    unit_name = get_object_or_404(Unit, pk=unit)
    objects = Leave.objects.filter(start_date__year=tyear,start_date__month=int(month),leave_type=lt,employee__curempdivision__unit_id=int(unit),  hr_confirm=True, is_done=True)
    context = {
        'title': 'Lista Licensa','legend': f'Lista Licensa Tinan {tyear}, Fulan {monthname}, Divizaun {unit_name.name}', 
        'objects': objects,
    }
    return render(request, 'leave_report/list.html', context)

@login_required
@allowed_users(allowed_roles=['admin','hr'])
def hrReportLeaveMonthUnitAll(request, month, unit):
    tyear = dt.now().year
    monthname = f_monthname(int(month))
    unit_name = get_object_or_404(Unit, pk=unit)
    objects = Leave.objects.filter(start_date__year=int(tyear),start_date__month=int(month),employee__curempdivision__unit_id=int(unit),  hr_confirm=True, is_done=True)
    context = {
        'title': 'Lista Licensa','legend': f'Lista Licensa iha Tinan {tyear}, Fulan {monthname}, Divizaun {unit_name.name}', 
        'objects': objects
    }
    return render(request, 'leave_report/list.html', context)

# work: YEAR TRIMESTRAL
@login_required
@allowed_users(allowed_roles=['admin','hr'])
def hrReportLeaveYearTri(request,pk, year, gtri):
    lt = get_object_or_404(LeaveType, pk=pk)
    trimestral = np.array([[1,'Trimestre I','01','04'],[2,'Trimestre II','04','07'],\
				[3,'Trimestre III','07','10'],[4,'Trimestre IV','10','13']])
    tri = int(gtri)-1
    tris = trimestral[tri]
    objects = Leave.objects.filter(leave_type=lt,start_date__year=year, start_date__month__gte=tris[2],  start_date__month__lte=tris[3], hr_confirm=True, is_done=True)
    context = {
        'title': 'Lista Licensa','legend': f'Lista Licensa {lt.name}, Tinan{year}, {tris[1]}', 
        'objects': objects, 
    }
    return render(request, 'leave_report/list.html', context)

@login_required
@allowed_users(allowed_roles=['adhrReportLeaveUnitmin','hr'])
def hrReportLeaveYearTriAll(request, year):
    data = []
    trimestral = np.array([[1,'Trimestre I','01','04'],[2,'Trimestre II','04','07'],\
				[3,'Trimestre III','07','10'],[4,'Trimestre IV','10','13']])
    for tris in trimestral:
        objects = Leave.objects.filter(start_date__year=year, start_date__month__gte=tris[2],  start_date__month__lte=tris[3],  is_active=True, hr_confirm=True, is_done=True)
        for i in objects:
            if i:
                data.append(i)
    context = {
        'title': 'Lista Licensa','legend': f'Lista Licensa Trimestral, Tinan {year}', 
        'objects': data
    }
    return render(request, 'leave_report/list.html', context)


# work: YEAR MONTH UNIT
@login_required
@allowed_users(allowed_roles=['admin','hr'])
def hrReportLeaveYearMonthUnit(request, pk,year, month, unit):
    monthname = f_monthname(int(month))
    lt = get_object_or_404(LeaveType, pk=pk)
    unit_name = get_object_or_404(Unit, pk=unit)
    objects = Leave.objects.filter(start_date__year=int(year),start_date__month=int(month),leave_type=lt,employee__curempdivision__unit_id=int(unit),  hr_confirm=True, is_done=True)
    context = {
        'title': 'Lista Licensa','legend': f'Lista Licensa Tinan {year},Fulan {monthname}, Divizaun {unit_name.name}', 
        'objects': objects,
    }
    return render(request, 'leave_report/list.html', context)

@login_required
@allowed_users(allowed_roles=['admin','hr'])
def hrReportLeaveYearMonthUnitAll(request,year, month, unit):
    monthname = f_monthname(int(month))
    unit_name = get_object_or_404(Unit, pk=unit)
    objects = Leave.objects.filter(start_date__year=int(year),start_date__month=int(month),employee__curempdivision__unit_id=int(unit),  hr_confirm=True, is_done=True)
    context = {
        'title': 'Lista Licensa','legend': f'Lista Licensa iha Tinan {year}, Fulan {monthname}, Divizaun {unit_name.name}', 
        'objects': objects
    }
    return render(request, 'leave_report/list.html', context)


# work: YEAR TRIMESTRAL UNIT
@login_required
@allowed_users(allowed_roles=['admin','hr'])
def hrReportLeaveYearTriUnit(request,pk, year, gtri, unit):
    lt = get_object_or_404(LeaveType, pk=pk)
    trimestral = np.array([[1,'Trimestre I','01','04'],[2,'Trimestre II','04','07'],\
				[3,'Trimestre III','07','10'],[4,'Trimestre IV','10','13']])
    tri = int(gtri)-1
    tris = trimestral[tri]
    unit_name = get_object_or_404(Unit, pk=unit)
    objects = Leave.objects.filter(leave_type=lt,start_date__year=int(year), start_date__month__gte=tris[2],  start_date__month__lte=tris[3], employee__curempdivision__unit_id=int(unit), hr_confirm=True, is_done=True)
    context = {
        'title': 'Lista Licensa','legend': f'Lista Licensa {lt.name}, Tinan{year}, {tris[1]}, Divizaun {unit_name.name}', 
        'objects': objects, 
    }
    return render(request, 'leave_report/list.html', context)

@login_required
@allowed_users(allowed_roles=['adhrReportLeaveUnitmin','hr'])
def hrReportLeaveYearTriUnitAll(request, year, unit):
    data = []
    unit_name = get_object_or_404(Unit, pk=unit)
    trimestral = np.array([[1,'Trimestre I','01','04'],[2,'Trimestre II','04','07'],\
				[3,'Trimestre III','07','10'],[4,'Trimestre IV','10','13']])
    for tris in trimestral:
        objects = Leave.objects.filter(start_date__year=int(year), start_date__month__gte=tris[2],  start_date__month__lte=tris[3], employee__curempdivision__unit_id=int(unit), is_active=True, hr_confirm=True, is_done=True)
        for i in objects:
            if i:
                data.append(i)
    context = {
        'title': 'Lista Licensa','legend': f'Lista Licensa Trimestral, Tinan {year}, Divizaun {unit_name.name}', 
        'objects': data
    }
    return render(request, 'leave_report/list.html', context)

# work: MONTH
# @login_required
# @allowed_users(allowed_roles=['admin','hr'])
# def hrReportLeaveDayMonth(request, date):
#     monthname = f_monthname(int(date.month))
#     objects = Leave.objects.filter(start_date=date.date(), hr_confirm=True, is_done=True)
#     context = {
#         'title': 'Lista Licensa','legend': f'Lista Licensa Loron {date.day}-{monthname}-{date.year}', 
#         'objects': objects,
#     }
#     return render(request, 'leave_report/list.html', context)


# Generated by Django 3.2 on 2022-12-10 14:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0024_alter_leave_is_active'),
    ]

    operations = [
        migrations.AddField(
            model_name='leave',
            name='end_date_status',
            field=models.CharField(blank=True, choices=[('Dader', 'Dader'), ('Lokraik', 'Lokraik')], max_length=15, null=True, verbose_name='Horas Data Remata'),
        ),
        migrations.AddField(
            model_name='leave',
            name='start_date_status',
            field=models.CharField(blank=True, choices=[('Dader', 'Dader'), ('Lokraik', 'Lokraik')], max_length=15, null=True, verbose_name='Horas Data Hahu'),
        ),
    ]



# Generated by Django 3.2 on 2023-02-02 00:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0067_leave_is_send_to_div'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='leave',
            name='end_datetime',
        ),
        migrations.RemoveField(
            model_name='leave',
            name='start_datetime',
        ),
        migrations.AddField(
            model_name='leave',
            name='end_time',
            field=models.TimeField(blank=True, null=True, verbose_name='Horas Remata'),
        ),
        migrations.AddField(
            model_name='leave',
            name='start_time',
            field=models.TimeField(blank=True, null=True, verbose_name='Horas Hahu'),
        ),
    ]



from django.urls import path
from . import views

urlpatterns = [
	### Staff
	path('dash/', views.hrLeaveReportDash, name="hr-leave-r-dash"),
	path('type/<int:pk>/<int:year>/list/', views.hrLeaveReportLeaveTypeList, name="hr-leave-r-list-type"),
	path('type/<int:year>/list-all/', views.hrLeaveReportLeaveTypeListAll, name="hr-leave-r-list-all"),
	path('type/month/<str:date>/list/', views.hrLeaveReportLeaveMonthTypeList, name="hr-leave-r-list-day"),
	# YEARS
	path('type/year/<int:pk>/<int:year>/', views.hrReportLeaveYear, name="hr-report-year"),
	path('type/year-all/<int:year>/', views.hrReportLeaveYearAll, name="hr-report-year-all"),
	# UNITS
	path('type/unit/<int:pk>/<int:pk2>/', views.hrReportLeaveUnit, name="hr-report-unit"),
	path('type/unit-all/<int:pk>/', views.hrReportLeaveUnitAll, name="hr-report-unit-all"),
	# TRI
	path('type/tri/<int:pk>/<int:pk2>/', views.hrReportLeaveTri, name="hr-report-tri"),
	path('type/tri-all/', views.hrReportLeaveTriAll, name="hr-report-tri-all"),
	# MONTH 
	path('type/month/<int:pk>/<int:month>/', views.hrReportLeaveMonth, name="hr-report-month"),
	path('type/month-all/<int:month>/', views.hrReportLeaveMonthAll, name="hr-report-month-all"),
	# YEAR UNIT 
	path('type/year-unit/<int:pk>/<int:pk2>/<int:year>/', views.hrReportLeaveYearUnit, name="hr-report-year-unit"),
	path('type/year-unit-all/<int:pk>/<int:year>/', views.hrReportLeaveYearUnitAll, name="hr-report-year-unit-all"),
	# YEAR MONTH 
	path('type/year-month/<int:pk>/<int:year>/<int:month>/', views.hrReportLeaveMonth, name="hr-report-year-month"),
	path('type/year-month-all/<int:year>/<int:month>/', views.hrReportLeaveMonthAll, name="hr-report-year-month-all"),
	# MONTH UNIT 
	path('type/month-unit/<int:pk>/<int:month>/<int:unit>/', views.hrReportLeaveMonthUnit, name="hr-report-month-unit"),
	path('type/month-unit-all/<int:month>/<int:unit>/', views.hrReportLeaveMonthUnitAll, name="hr-report-month-unit-all"),
	# YEAR TRI 
	path('type/year-tri/<int:pk>/<int:year>/<int:gtri>/', views.hrReportLeaveYearTri, name="hr-report-year-tri"),
	path('type/year-tri-all/<int:year>/', views.hrReportLeaveYearTriAll, name="hr-report-year-tri-all"),
	# YEAR MONTH UNIT 
	path('type/year-month-unit/<int:pk>/<int:year>/<int:month>/<int:unit>/', views.hrReportLeaveYearMonthUnit, name="hr-report-year-month-unit"),
	path('type/year-month-unit-all/<int:year>/<int:month>/<int:unit>/', views.hrReportLeaveYearMonthUnitAll, name="hr-report-year-month-unit-all"),
	# YEAR TRI UNIT 
	path('type/year-tri-unit/<int:pk>/<int:year>/<int:gtri>/<int:unit>/', views.hrReportLeaveYearTriUnit, name="hr-report-year-tri-unit"),
	path('type/year-tri-unit-all/<int:year>/<int:unit>/', views.hrReportLeaveYearTriUnitAll, name="hr-report-year-tri-unit-all"),
]


# Generated by Django 3.2 on 2022-12-20 08:29

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0046_month_year'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='month',
            name='is_active',
        ),
        migrations.RemoveField(
            model_name='year',
            name='is_active',
        ),
        migrations.CreateModel(
            name='LeavePeriod',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('is_active', models.BooleanField(default=False)),
                ('end_month', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='end_month', to='leave.month', verbose_name='Fulan Remata')),
                ('end_year', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='end_year', to='leave.year', verbose_name='Tinan Remata')),
                ('start_month', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='start_month', to='leave.month', verbose_name='Fulan Hahu')),
                ('start_year', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='start_year', to='leave.year', verbose_name='Tinan Hahu')),
            ],
        ),
        migrations.AddField(
            model_name='leave',
            name='leave_period',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='leaveperiod', to='leave.leaveperiod', verbose_name='Leave Period'),
        ),
    ]



import datetime
from django.shortcuts import render, redirect, get_object_or_404
from django.contrib.auth.decorators import login_required
import employee
from settings_app.decorators import allowed_users
from django.contrib import messages
from employee.models import CurEmpDivision, Employee
from leave.models import Leave, LeaveCount, LeaveDelegate
from leave.forms import LeaveDelegateForm2, LeaveForm, LeaveDelegateForm1
from settings_app.utils import getnewid
from settings_app.user_utils import c_staff

###


import datetime
import numpy as np
from django.shortcuts import render, redirect, get_object_or_404
from django.db.models import Count, Q, Sum
from rest_framework.views import APIView
from rest_framework.response import Response
from rest_framework import status
from rest_framework.authentication import SessionAuthentication, BasicAuthentication
from rest_framework.permissions import IsAuthenticated
from employee.models import Employee, CurEmpDivision, FormalEducation, LocationTL, Country
from contract.models import EmpPosition
from custom.models import EducationLevel, Unit, Department, Municipality
from settings_app.user_utils import c_unit, c_dep
from leave.models import LeaveCount, Leave, LeavePeriod, LeaveType
from datetime import datetime as dt
from settings_app.utils import getnewid, f_monthname

def count_leave(emp):
    leave_type = LeaveType.objects.all()
    leave = []
    l_name = []
    name = []
    for l in leave_type:

        period = LeavePeriod.objects.filter(employee=emp, is_active=True).last()
        lcount = Leave.objects.filter(employee=emp, leave_period=period, leave_type=l, hr_confirm=True, is_done=True).count()
        leave.append(lcount)
        name.append(l.name)
        leave.append(lcount)
        l_name.append([l.name])
    return name, leave

class APIEmpLeave(APIView):
    authentication_classes = [SessionAuthentication, BasicAuthentication]
    permission_classes = [IsAuthenticated]
    def get(self, request, format=None):
        object = list()
        group = request.user.groups.all()[0].name
        employee = Employee.objects.filter(status_id=1)
        categories = list()
        data = list()
        month = datetime.date.today().strftime("%B")
        year = datetime.date.today().strftime("%Y")
        legend = f'Summary all Staff as of  {month} {year}'


        al = list()
        sicleave = list()
        spleave = list()
        mtleave = list()
        ptleave = list()
        chilleave = list()

        for emp in employee:
            period = LeavePeriod.objects.filter(employee=emp, is_active=True).last()
            aleave = Leave.objects.filter(employee=emp, leave_period=period, leave_type_id=1, hr_confirm=True, is_done=True).count()
            sickleave = Leave.objects.filter(employee=emp, leave_period=period, leave_type_id=2, hr_confirm=True, is_done=True).count()
            specialleave = Leave.objects.filter(employee=emp, leave_period=period, leave_type_id=3, hr_confirm=True, is_done=True).count()
            matleave = Leave.objects.filter(employee=emp, leave_period=period, leave_type_id=4, hr_confirm=True, is_done=True).count()
            patleave = Leave.objects.filter(employee=emp, leave_period=period, leave_type_id=5, hr_confirm=True, is_done=True).count()
            childleave = Leave.objects.filter(employee=emp, leave_period=period, leave_type_id=6, hr_confirm=True, is_done=True).count()
            categories.append(f'{emp.first_name} {emp.last_name}')
            al.append(aleave)
            sicleave.append(sickleave)
            spleave.append(specialleave)
            mtleave.append(matleave)
            ptleave.append(patleave)
            chilleave.append(childleave)
        data = {
            
            'categories': categories, 'legend': legend,
            'al': al,'sicleave': sicleave,'spleave': spleave,
            'matleave': mtleave, 'patleave':ptleave, 'chileave': childleave
        }

        return Response(data)


class APIEmpLeaveType(APIView):
    authentication_classes = [SessionAuthentication, BasicAuthentication]
    permission_classes = [IsAuthenticated]
    def get(self, request, format=None):
        label = list()
        obj = list()
        leave_type = LeaveType.objects.all()
        for i in leave_type:
            annual_leave = Leave.objects.filter(leave_type=i,leave_period__is_active=True, is_active=True, hr_confirm=True, is_done=True).count()
            obj.append({
                'name': i.name,
                'y': annual_leave
            })
        data = { 'label': 'All staff total days Leaves', 
        'obj': obj,  'label2':label}
        return Response(data)

class APIEmpLeaveType2(APIView):
    authentication_classes = [SessionAuthentication, BasicAuthentication]
    permission_classes = [IsAuthenticated]
    def get(self, request,year, format=None):
        label = []
        obj = []
        leave_type = LeaveType.objects.all()
        for i in leave_type:
            cleave = Leave.objects.filter(leave_type=i, start_date__year=year,  hr_confirm=True, is_done=True).count()
            obj.append(cleave)
            label.append(i.name)
        data = { 'label': f'Distribuisaun Licensa Tinan {year}', 
        'obj': obj,  'label2':label}
        return Response(data)

class APIEmpLeaveType3(APIView):
    authentication_classes = [SessionAuthentication, BasicAuthentication]
    permission_classes = [IsAuthenticated]
    def get(self, request,year,month, format=None):
        label = []
        obj = []
        leave_type = LeaveType.objects.all()
        for i in leave_type:
            cleave = Leave.objects.filter(leave_type=i, start_date__year=year, start_date__month=month,  hr_confirm=True, is_done=True).count()
            obj.append(cleave)
            label.append(i.name)
        data = { 'label': 'All staff total days Leaves by Year and Month', 
        'obj': obj,  'label2':label}
        return Response(data)

class APIEmpLeaveUnit(APIView):
    authentication_classes = [SessionAuthentication, BasicAuthentication]
    permission_classes = [IsAuthenticated]
    def get(self, request, unit, format=None):
        label = []
        obj = []
        leave_type = LeaveType.objects.all()
        unit_name = get_object_or_404(Unit, pk=unit)
        for i in leave_type:
            cleave = Leave.objects.filter(leave_type=i,employee__curempdivision__unit_id=unit,  hr_confirm=True, is_done=True).count()
            obj.append(cleave)
            label.append(i.name)
        data = { 'label': f'Distribuisaun Licensa iha {unit_name.name}' , 
        'obj': obj,  'label2':label}
        return Response(data)

class APIEmpLeaveMonth(APIView):
    authentication_classes = [SessionAuthentication, BasicAuthentication]
    permission_classes = [IsAuthenticated]
    def get(self, request,month, format=None):
        label = []
        obj = []
        tyear = dt.now().year
        monthname = f_monthname(int(month))
        leave_type = LeaveType.objects.all()
        for i in leave_type:
            cleave = Leave.objects.filter(leave_type=i,start_date__year=tyear, start_date__month=int(month),  hr_confirm=True, is_done=True).count()
            obj.append(cleave)
            label.append(i.name)
        data = { 'label': f'Distribuisaun Licensa Tinan {tyear} fulan {monthname}', 
        'obj': obj,  'label2':label}
        return Response(data)

class APIEmpLeaveYearUnit(APIView):
    authentication_classes = [SessionAuthentication, BasicAuthentication]
    permission_classes = [IsAuthenticated]
    def get(self, request,unit, year, format=None):
        label = []
        obj = []
        leave_type = LeaveType.objects.all()
        unit_name = get_object_or_404(Unit, pk=unit)
        for i in leave_type:
            cleave = Leave.objects.filter(start_date__year=int(year),leave_type=i,employee__curempdivision__unit_id=int(unit),  hr_confirm=True, is_done=True).count()
            obj.append(cleave)
            label.append(i.name)
        data = { 'label': f'Distribuisaun Licensa Tinan {year} Divizaun {unit_name.name}', 
        'obj': obj,  'label2':label}
        return Response(data)

class APIEmpLeaveYearMonth(APIView):
    authentication_classes = [SessionAuthentication, BasicAuthentication]
    permission_classes = [IsAuthenticated]
    def get(self, request,month, year, format=None):
        label = []
        obj = []
        leave_type = LeaveType.objects.all()
        monthname = f_monthname(int(month))
        for i in leave_type:
            cleave = Leave.objects.filter(leave_type=i,start_date__year=int(year), start_date__month=int(month),  hr_confirm=True, is_done=True).count()
            obj.append(cleave)
            label.append(i.name)
        data = { 'label': f'Distribuisaun Licensa Tinan {year} Fulan {monthname}', 
        'obj': obj,  'label2':label}
        return Response(data)

class APIEmpLeaveMonthUnit(APIView):
    authentication_classes = [SessionAuthentication, BasicAuthentication]
    permission_classes = [IsAuthenticated]
    def get(self, request,month,unit, format=None):
        label = []
        obj = []
        tyear = dt.now().year
        monthname = f_monthname(int(month))
        unit_name = get_object_or_404(Unit, pk=unit)
        leave_type = LeaveType.objects.all()
        for i in leave_type:
            cleave = Leave.objects.filter(leave_type=i,start_date__year=tyear, start_date__month=int(month), employee__curempdivision__unit_id=int(unit),  hr_confirm=True, is_done=True).count()
            obj.append(cleave)
            label.append(i.name)
        data = { 'label': f'Distribuisaun Licensa Tinan {tyear}, Fulan {monthname}, Divizaun {unit_name.name} ', 
        'obj': obj,  'label2':label}
        return Response(data)
    

class APIEmpLeaveTri(APIView):
    authentication_classes = [SessionAuthentication, BasicAuthentication]
    permission_classes = [IsAuthenticated]
    def get(self, request, tri, format=None):
        trimestral = np.array([[1,'Trimetre I','01','04'],[2,'Trimetre II','04','07'],\
				[3,'Trimetre III','07','10'],[4,'Trimetre IV','10','13']])
        gtri = int(tri)-1
        tris = trimestral[gtri]
        tyear = dt.now().year
        label = []
        obj = []
        leave_type = LeaveType.objects.all()
        for i in leave_type:
            cleave = Leave.objects.filter(leave_type=i,start_date__year=tyear, start_date__month__gte=tris[2],  start_date__month__lte=tris[3], hr_confirm=True, is_done=True).count()
            obj.append(cleave)
            label.append(i.name)
        data = { 'label': f'Distribuisaun Licensa Tinan {tyear} {tris[1]}', 
        'obj': obj,  'label2':label}
        return Response(data)


class APIEmpLeaveYearTri(APIView):
    authentication_classes = [SessionAuthentication, BasicAuthentication]
    permission_classes = [IsAuthenticated]
    def get(self, request, year,tri, format=None):
        trimestral = np.array([[1,'Trimetre I','01','04'],[2,'Trimetre II','04','07'],\
				[3,'Trimetre III','07','10'],[4,'Trimetre IV','10','13']])
        gtri = int(tri)-1
        tris = trimestral[gtri]
        label = []
        obj = []
        leave_type = LeaveType.objects.all()
        for i in leave_type:
            cleave = Leave.objects.filter(leave_type=i,start_date__year=year, start_date__month__gte=tris[2],  start_date__month__lte=tris[3], hr_confirm=True, is_done=True).count()
            obj.append(cleave)
            label.append(i.name)
        data = { 'label': f'Distribuisaun Licensa Tinan {year} {tris[1]}', 
        'obj': obj,  'label2':label}
        return Response(data)

class APIEmpLeaveYearMonthUnit(APIView):
    authentication_classes = [SessionAuthentication, BasicAuthentication]
    permission_classes = [IsAuthenticated]
    def get(self, request,month, year, unit, format=None):
        label = []
        obj = []
        leave_type = LeaveType.objects.all()
        monthname = f_monthname(int(month))
        unit_name = get_object_or_404(Unit, pk=unit)
        for i in leave_type:
            cleave = Leave.objects.filter(start_date__year=int(year),start_date__month=int(month),leave_type=i,employee__curempdivision__unit_id=int(unit),  hr_confirm=True, is_done=True).count()
            obj.append(cleave)
            label.append(i.name)
        data = { 'label': f'Distribuisaun Licensa Tinan {year}, Fulan {monthname}, Divizaun {unit_name.name}', 
        'obj': obj,  'label2':label}
        return Response(data)

class APIEmpLeaveYearTriUnit(APIView):
    authentication_classes = [SessionAuthentication, BasicAuthentication]
    permission_classes = [IsAuthenticated]
    def get(self, request, year,tri,unit, format=None):
        trimestral = np.array([[1,'Trimetre I','01','04'],[2,'Trimetre II','04','07'],\
				[3,'Trimetre III','07','10'],[4,'Trimetre IV','10','13']])
        gtri = int(tri)-1
        tris = trimestral[gtri]
        label = []
        obj = []
        unit_name = get_object_or_404(Unit, pk=unit)
        leave_type = LeaveType.objects.all()
        for i in leave_type:
            cleave = Leave.objects.filter(leave_type=i,start_date__year=year, start_date__month__gte=tris[2],  start_date__month__lte=tris[3],employee__curempdivision__unit_id=int(unit), hr_confirm=True, is_done=True).count()
            obj.append(cleave)
            label.append(i.name)
        data = { 'label': f'Distribuisaun Licensa Tinan {year}, {tris[1]}, {unit_name.name}', 
        'obj': obj,  'label2':label}
        return Response(data)


# Generated by Django 4.0 on 2022-09-23 01:15

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('employee', '0004_employee_emp_id'),
        ('leave', '0003_rename_taskdelegate_leavedelegate'),
    ]

    operations = [
        migrations.AlterField(
            model_name='leavedelegate',
            name='employee',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='leavedelegate', to='employee.employee', verbose_name='Delega ba'),
        ),
    ]



from django.shortcuts import render, get_object_or_404
from django.contrib.auth.decorators import login_required
from settings_app.decorators import allowed_users
from django.db.models import Sum, Count, Q
from leave.models import Leave, LeaveDE, LeaveDelegate, LeaveHR, LeaveUnit,LeaveDep
from settings_app.user_utils import c_unit, c_staff

@login_required
@allowed_users(allowed_roles=['de','deputy'])
def deLeaveApprList(request):
	group = request.user.groups.all()[0].name
	objects = Leave.objects.filter((Q(dep_send_pr=True)|Q(unit_send_pr=True)), is_finish=False).all().order_by('-start_date')
	context = {
		'group': group, 'objects': objects,
		'title': 'Lista Licensa hodi Aprova', 'legend': 'Lista Pedido Husu Aprovasaun Licensa'
	}
	return render(request, 'leave/de_appr_list.html', context)

@login_required
@allowed_users(allowed_roles=['de','deputy'])
def deLeaveList(request):
	group = request.user.groups.all()[0].name
	c_emp = c_staff(request.user)
	objects = Leave.objects.filter(employee=c_emp).all().order_by('-start_date')
	context = {
		'group': group, 'objects': objects,
		'title': 'Lista Licensa', 'legend': 'Lista Licensa'
	}
	return render(request, 'leave/de_list.html', context)

@login_required
@allowed_users(allowed_roles=['de','deputy'])
def deLeaveDetail(request, hashid):
	group = request.user.groups.all()[0].name
	leave = get_object_or_404(Leave, hashed=hashid)
	cgroup = leave.user.groups.all()[0].name
	leavedel = LeaveDelegate.objects.filter(leave=leave).first()
	leaveunit = LeaveUnit.objects.filter(leave=leave).first()
	leavedep = LeaveDep.objects.filter(leave=leave).first()
	leavehr = LeaveHR.objects.filter(leave=leave).first()
	leavede = LeaveDE.objects.filter(leave=leave).first()
	context = {
		'group': group, 'leave': leave, 'leavedel': leavedel, 'leaveunit': leaveunit,
        'leavehr': leavehr, 'leavede': leavede, 'leavedep': leavedep,
		'title': 'Detalha Licensa', 'legend': 'Detalha Licensa', 'cgroup':cgroup
	}
	return render(request, 'leave/de_detail.html', context)
@login_required
@allowed_users(allowed_roles=['de','deputy'])
def deLeaveApprDetail(request, hashid):
	group = request.user.groups.all()[0].name
	leave = get_object_or_404(Leave, hashed=hashid)
	cgroup = leave.user.groups.all()[0].name
	leavedel = LeaveDelegate.objects.filter(leave=leave).first()
	leaveunit = LeaveUnit.objects.filter(leave=leave).first()
	leavedep = LeaveDep.objects.filter(leave=leave).first()
	leavehr = LeaveHR.objects.filter(leave=leave).first()
	leavede = LeaveDE.objects.filter(leave=leave).first()
	context = {
		'group': group, 'leave': leave, 'leavedel': leavedel, 'leaveunit': leaveunit,
        'leavehr': leavehr, 'leavede': leavede, 'leavedep': leavedep,
		'title': 'Detalha Licensa', 'legend': 'Detalha Licensa', 'cgroup':cgroup
	}
	return render(request, 'leave/de_appr_detail.html', context)


# Generated by Django 3.2 on 2023-01-13 15:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0059_auto_20230110_1535'),
    ]

    operations = [
        migrations.AddField(
            model_name='leavecount',
            name='update_date',
            field=models.DateField(blank=True, null=True),
        ),
    ]



# Generated by Django 3.2 on 2023-01-10 06:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('leave', '0058_leaveperiod_employee'),
    ]

    operations = [
        migrations.AddField(
            model_name='leaveperiod',
            name='end_date',
            field=models.DateField(blank=True, null=True, verbose_name='Data Remate'),
        ),
        migrations.AddField(
            model_name='leaveperiod',
            name='start_date',
            field=models.DateField(blank=True, null=True, verbose_name='Data Hahu'),
        ),
    ]



import datetime
from django.shortcuts import render, redirect, get_object_or_404
from django.contrib.auth.decorators import login_required
import employee
from settings_app.decorators import allowed_users
from django.contrib import messages
from employee.models import CurEmpDivision, Employee
from leave.models import Leave, LeaveCount, LeaveDelegate, LeaveUnit, LeaveDep, LeavePeriod
from leave.forms import LeaveDelegateForm2, LeaveForm, LeaveDelegateForm1
from contract.models import EmpPosition
from settings_app.utils import getnewid
from settings_app.user_utils import c_staff, c_unit, c_dep
from datetime import datetime as dt
import pandas as pd
from leave.utils import calculate_days, koko
from django.db.models import Q
from leave.utils import count_day
from log.utils import log_action
from leave.utils_2 import koko2, calculate_leave_days
@login_required
def LeaveAdd(request):
	group = request.user.groups.all()[0].name
	c_emp = []
	if group == "staff":
		c_emp = c_staff(request.user)
	elif group == "unit":
		c_emp, _ = c_unit(request.user)
	else:
		c_emp = c_staff(request.user)
	lp = LeavePeriod.objects.filter(employee=c_emp,is_active=True).exists()
	period = LeavePeriod.objects.filter(employee=c_emp,is_active=True).last()
	
	if period :

		empdiv = CurEmpDivision.objects.get(employee=c_emp)
		if lp == True:
			if request.method == 'POST':
				newid, new_hashid = getnewid(Leave)
				form = LeaveForm(request.POST, request.FILES)
				if form.is_valid():
					today = dt.today().date()
					leave_period = LeavePeriod.objects.filter(employee=c_emp,is_active=True).last()
					start_date = form.cleaned_data.get('start_date')
					end_date = form.cleaned_data.get('end_date')
					start_time_status = form.cleaned_data.get('start_time_status')
					end_time_status = form.cleaned_data.get('end_time_status')

					start_dt = dt(start_date.year, start_date.month, start_date.day)
					end_dt = dt(end_date.year, end_date.month, end_date.day)
					try:
						days = calculate_leave_days(start_dt, end_dt, start_time_status, end_time_status)
					except ValueError as e:
						messages.warning(request, str(e))
						return render(request, 'leave/form.html', 
		    				{ 
							'message':e, 
							'group': group, 'c_emp': c_emp, 'empdiv': empdiv, 'form': form, 'page': 'apply',
							'title': 'Formulario Aplika Licensa', 'legend': 'Formulario Aplika Licensa'
							}
							)
					days = round(float(days),2)
					last_two_digits = str(days).split('.')[1][:2]
					last_two_digits = int(last_two_digits)

					min_month = f'{leave_period.start_year.year}-{leave_period.start_month.code}'
					max_month = f'{leave_period.end_year.year}-{leave_period.end_month.code}'
					date1 = pd.to_datetime(start_date, format="%Y %m").date()
					date2 = pd.to_datetime(end_date, format="%Y %m").date()

					start_date_period = pd.to_datetime(min_month, format="%Y %m").date()
					end_date_period = pd.to_datetime(max_month, format="%Y %m").date()
					start_month = date1
					# cal_day = count_day(start_date, end_date)

					if start_date_period <= start_month <= end_date_period + datetime.timedelta(days=29):
						
						leave_this_month = LeaveCount.objects.filter(period=leave_period, employee=c_emp, leave_type_id=1, update_date__lte=today).last()
						if leave_this_month.balance >= 0.5:
							if   days <= leave_this_month.balance or days <= leave_this_month.balance + 5 :

								if days < 30  or days >= 30:
									
									if last_two_digits == int(5) or last_two_digits == int(0):
										instance = form.save(commit=False)
										instance.id = newid
										instance.employee = c_emp
										if group == "unit":
											instance.unit_confirm = True
											instance.unit_send = True
										if group == "dep":
											instance.is_lock = True
											instance.is_send = True
										if group == "de":
											instance.is_lock = True
											instance.is_approve = True
											instance.is_finish = True
											instance.is_finish = True
											instance.pr_send = True
											instance.obs = "Sim"
											instance.pr_approve = True
										instance.datetime = datetime.datetime.now()
										instance.user = request.user
										instance.hashed = new_hashid
										instance.leave_period  = period
										instance.days = days
										instance.save()
										if group == "unit":
											leaveunit = LeaveUnit.objects.filter(leave_id=newid).first()
											leaveunit.obs = "Sim"
											leaveunit.user = request.user
											leaveunit.datetime = datetime.datetime.now()
											leaveunit.save()
										if group == "dep":

											leavedep = LeaveDep.objects.filter(leave_id=newid).first()
											leavedep.obs = "Sim"
											leavedep.user = request.user
											leavedep.datetime = datetime.datetime.now()
											leavedep.save()
										
										messages.success(request, f'Aumeta sucessu.')
										if group == "staff" or group == "hr": return redirect('leave-s-detail', hashid=new_hashid)
										if group == "dep": return redirect('leave-dep-detail', hashid=new_hashid)
										elif group == "unit" or group == "deputy": return redirect('leave-c-detail', hashid=new_hashid)
										elif group == "de" : return redirect('leave-de-appr-detail', hashid=new_hashid)
									else:
										messages.error(request,'Total loron nebe ita prienche latuir formato!! Total Loron Nebe Valido: *.00 Sura ba loron  no  *.5 Sura ba "Stengah Hari" ')
								else:
									messages.error(request, f'Loron nebe hili barak liu. Halo favor hare regulamentu konaba total licenca.')
							else:
								messages.error(request, f'Loron nebe hili barak liu. Halo favor hare regulamentu konaba total licenca.')
						else:
							messages.error(request, f'Loron nebe hili barak liu. Halo favor hare regulamentu konaba total licenca.')
					else:
						messages.error(request,'Data hahu laiha periode ida ne nia laran. Halo Favor Kontakto Rekurso Humano hodi Kria Uluk Periode Licensa Foun!')
			else: form = LeaveForm()
		else:
			messages.error(request, 'Periode ba Lisensa seidauk determina')
			if group == "staff": return redirect('leave-s-list')
			if group == "dep": return redirect('leave-dep-list')
			elif group == "unit": return redirect('leave-c-list')
			elif group == "de": return redirect('leave-de-list')
			elif group == "deputy": return redirect('leave-de-list')
			elif group == "hr": return redirect('leave-hr-list')
		context = {
			'group': group, 'c_emp': c_emp, 'empdiv': empdiv, 'form': form, 'page': 'apply',
			'title': 'Formulario Aplika Licensa', 'legend': 'Formulario Aplika Licensa'
		}
		return render(request, 'leave/form.html', context)
	else:
		messages.error(request, 'Periode Licensa seidauk kria. Halo Favor Kontakto Rekurso Humano')
		if group == "staff": return redirect('leave-s-list')
		if group == "dep": return redirect('leave-dep-list')
		elif group == "unit": return redirect('leave-c-list')
		elif group == "de": return redirect('leave-de-list')
		elif group == "deputy": return redirect('leave-de-list')
		elif group == "hr": return redirect('leave-hr-list')


@login_required
def LeaveUpdate(request, hashid):
	group = request.user.groups.all()[0].name
	leave = get_object_or_404(Leave, hashed=hashid)
	c_emp = []
	if group == "staff":
		c_emp = c_staff(request.user)
	elif group == "unit":
		c_emp, _ = c_unit(request.user)
	else:
		c_emp = c_staff(request.user)
	lp = LeavePeriod.objects.filter(employee=c_emp,is_active=True).exists()
	period = LeavePeriod.objects.filter(employee=c_emp,is_active=True).last()
	
	if period :

		empdiv = CurEmpDivision.objects.get(employee=c_emp)
		if lp == True:
			if request.method == 'POST':
				form = LeaveForm(request.POST,  request.FILES, instance=leave)
				if form.is_valid():
					today = dt.today().date()
					leave_period = LeavePeriod.objects.filter(employee=c_emp,is_active=True).last()
					start_date = form.cleaned_data.get('start_date')
					end_date = form.cleaned_data.get('end_date')
					start_time_status = form.cleaned_data.get('start_time_status')
					end_time_status = form.cleaned_data.get('end_time_status')

					start_dt = dt(start_date.year, start_date.month, start_date.day)
					end_dt = dt(end_date.year, end_date.month, end_date.day)
					try:
						days = calculate_leave_days(start_dt, end_dt, start_time_status, end_time_status)
					except ValueError as e:
						messages.warning(request, str(e))
						return render(request, 'leave/form.html', 
		    				{ 
							'message':e, 
							'group': group, 'c_emp': c_emp, 'empdiv': empdiv, 'form': form, 'page': 'apply',
							'title': 'Formulario Aplika Licensa', 'legend': 'Formulario Aplika Licensa'
							}
							)
					days = round(float(days),2)
					last_two_digits = str(days).split('.')[1][:2]
					last_two_digits = int(last_two_digits)

					min_month = f'{leave_period.start_year.year}-{leave_period.start_month.code}'
					max_month = f'{leave_period.end_year.year}-{leave_period.end_month.code}'
					date1 = pd.to_datetime(start_date, format="%Y %m").date()
					date2 = pd.to_datetime(end_date, format="%Y %m").date()

					start_date_period = pd.to_datetime(min_month, format="%Y %m").date()
					end_date_period = pd.to_datetime(max_month, format="%Y %m").date()
					start_month = date1
					# cal_day = count_day(start_date, end_date)

					if start_date_period <= start_month <= end_date_period + datetime.timedelta(days=29):
						
						leave_this_month = LeaveCount.objects.filter(period=leave_period, employee=c_emp, leave_type_id=1, update_date__lte=today).last()
						if leave_this_month.balance >= 0.5:
							if   days <= leave_this_month.balance or days <= leave_this_month.balance + 5 :

								if days < 30  or days >= 30:
									
									if last_two_digits == int(5) or last_two_digits == int(0):
										instance = form.save(commit=False)
										instance.employee = c_emp
										if group == "unit":
											instance.unit_confirm = True
											instance.unit_send = True
										if group == "dep":
											instance.is_lock = True
											instance.is_send = True
										if group == "de":
											instance.is_lock = True
											instance.is_approve = True
											instance.is_finish = True
											instance.is_finish = True
											instance.pr_send = True
											instance.obs = "Sim"
											instance.pr_approve = True
										instance.datetime = datetime.datetime.now()
										instance.user = request.user
										instance.leave_period  = period
										instance.days = days
										instance.save()
										if group == "unit":
											leaveunit = LeaveUnit.objects.filter(leave_id=leave.pk).first()
											leaveunit.obs = "Sim"
											leaveunit.user = request.user
											leaveunit.datetime = datetime.datetime.now()
											leaveunit.save()
										if group == "dep":

											leavedep = LeaveDep.objects.filter(leave_id=leave.pk).first()
											leavedep.obs = "Sim"
											leavedep.user = request.user
											leavedep.datetime = datetime.datetime.now()
											leavedep.save()
										
										messages.success(request, f'Aumeta sucessu.')
										if group == "staff" or group == "hr": return redirect('leave-s-detail', hashid=hashid)
										if group == "dep": return redirect('leave-dep-detail', hashid=hashid)
										elif group == "unit" or group == "deputy": return redirect('leave-c-detail', hashid=hashid)
										elif group == "de" : return redirect('leave-de-appr-detail', hashid=hashid)
									else:
										messages.error(request,'Total loron nebe ita prienche latuir formato!! Total Loron Nebe Valido: *.00 Sura ba loron  no  *.5 Sura ba "Stengah Hari" ')
								else:
									messages.error(request, f'Loron nebe hili barak liu. Halo favor hare regulamentu konaba total licenca.')
							else:
								messages.error(request, f'Loron nebe hili barak liu. Halo favor hare regulamentu konaba total licenca.')
						else:
							messages.error(request, f'Loron nebe hili barak liu. Halo favor hare regulamentu konaba total licenca.')
					else:
						messages.error(request,'Data hahu laiha periode ida ne nia laran. Halo Favor Kontakto Rekurso Humano hodi Kria Uluk Periode Licensa Foun!')
			else: form = LeaveForm(instance=leave)
		else:
			messages.error(request, 'Periode ba Lisensa seidauk determina')
			if group == "staff": return redirect('leave-s-list')
			if group == "dep": return redirect('leave-dep-list')
			elif group == "unit": return redirect('leave-c-list')
			elif group == "de": return redirect('leave-de-list')
			elif group == "deputy": return redirect('leave-de-list')
			elif group == "hr": return redirect('leave-hr-list')
		context = {
			'group': group, 'c_emp': c_emp, 'empdiv': empdiv, 'form': form, 'page': 'apply',
			'title': 'Formulario Aplika Licensa', 'legend': 'Formulario Aplika Licensa'
		}
		return render(request, 'leave/form.html', context)
	else:
		messages.error(request, 'Periode Licensa seidauk kria. Halo Favor Kontakto Rekurso Humano')
		if group == "staff": return redirect('leave-s-list')
		if group == "dep": return redirect('leave-dep-list')
		elif group == "unit": return redirect('leave-c-list')
		elif group == "de": return redirect('leave-de-list')
		elif group == "deputy": return redirect('leave-de-list')
		elif group == "hr": return redirect('leave-hr-list')


# @login_required
# def LeaveUpdate(request, hashid):
# 	group = request.user.groups.all()[0].name
# 	c_emp = c_staff(request.user)
# 	empdiv = CurEmpDivision.objects.get(employee=c_emp)
# 	objects = get_object_or_404(Leave, hashed=hashid)
# 	if request.method == 'POST':
# 		form = LeaveForm(request.POST,request.FILES, instance=objects)
# 		if form.is_valid():
# 			instance = form.save(commit=False)
# 			instance.save()
# 			log_action(request, model=Leave._meta.model_name, action="Update",field_id=objects.pk)
# 			messages.success(request, f'Altera sucessu.')
# 			if group == "staff": return redirect('leave-s-detail', hashid=hashid)
# 			elif group == "hr": return redirect('leave-s-detail', hashid=hashid)
# 			elif group == "unit": return redirect('leave-c-detail', hashid=hashid)
# 	else: form = LeaveForm(instance=objects)
# 	context = {
# 		'group': group, 'c_emp': c_emp, 'empdiv': empdiv, 'form': form, 'page': 'apply',
# 		'title': 'Altera Aplikasaun', 'legend': 'Altera Aplikasaun'
# 	}
# 	return render(request, 'leave/form.html', context)

@login_required
def LeaveLock(request, hashid):
	group = request.user.groups.all()[0].name
	objects = get_object_or_404(Leave, hashed=hashid)
	objects.is_lock =  True
	objects.save()
	messages.success(request, f'Xavi.')
	if group == "staff": return redirect('leave-s-detail', hashid=hashid)
	elif group == "hr": return redirect('leave-s-detail', hashid=hashid)
	elif group == "unit": return redirect('leave-c-detail', hashid=hashid)
	elif group == "deputy": return redirect('leave-c-detail', hashid=hashid)

@login_required
def LeaveUnLock(request, hashid):
	group = request.user.groups.all()[0].name
	objects = get_object_or_404(Leave, hashed=hashid)
	objects.is_lock =  False
	objects.save()
	messages.success(request, f'Loke.')
	if group == "staff": return redirect('leave-s-detail', hashid=hashid)
	elif group == "hr": return redirect('leave-s-detail', hashid=hashid)
	elif group == "unit": return redirect('leave-c-detail', hashid=hashid)
	elif group == "deputy": return redirect('leave-c-detail', hashid=hashid)

@login_required
def LeaveSend(request, hashid):
	group = request.user.groups.all()[0].name
	objects = get_object_or_404(Leave, hashed=hashid)
	c_emp = c_staff(request.user)
	empdiv = CurEmpDivision.objects.get(employee=c_emp)
	if group == "staff" or group == "hr":
		check_ekipa = EmpPosition.objects.filter(Q(department__isnull=False)&Q(department=empdiv.department), is_active=True, is_manager=True).exists()
		check_div = EmpPosition.objects.filter(Q(unit__isnull=False)&Q(unit=empdiv.unit), is_active=True, is_manager=True).exists()
		if check_ekipa and check_div or check_ekipa:
			objects.is_send =  True
			objects.is_finish =  False
			objects.save()
			messages.success(request, f'Manda ona.')
		elif check_div:
			objects.is_send_to_div =  True
			objects.is_finish =  False
			objects.save()
			messages.success(request, f'Manda ona.')
		else:
			messages.error(request, "Funsionario Refere Laiha Chefe Ekipa no Chefe Divizaun, Halo favor kontakto Rekurso Humano")
		if group == "staff": return redirect('leave-s-detail', hashid=hashid)
		elif group == "hr": return redirect('leave-s-detail', hashid=hashid)
		elif group == "unit": return redirect('leave-c-detail', hashid=hashid)

@login_required
def LeaveUnitSend(request, hashid):
	group = request.user.groups.all()[0].name
	objects = get_object_or_404(Leave, hashed=hashid)
	if group == 'unit':
		objects.unit_send_pr =  True
	if group == 'deputy':
		objects.unit_send_pr =  True
	objects.is_finish =  False
	objects.save()
	messages.success(request, f'Manda ona ba Presidente')
	return redirect('leave-c-detail', hashid=hashid)

@login_required
def LeaveUnitDone(request, hashid):
	group = request.user.groups.all()[0].name
	objects = get_object_or_404(Leave, hashed=hashid)
	objects.is_done =  True
	objects.save()
	messages.success(request, f'Susesi Termina Licensa')
	return redirect('leave-c-detail', hashid=hashid)

@login_required
def LeaveDelegUpdate(request, hashid):
	group = request.user.groups.all()[0].name
	c_emp = c_staff(request.user)
	empdiv = CurEmpDivision.objects.get(employee=c_emp)
	leave = get_object_or_404(Leave, hashed=hashid)
	objects = LeaveDelegate.objects.get(leave=leave)
	if request.method == 'POST':
		form = LeaveDelegateForm1(request.POST, instance=objects)
		if form.is_valid():
			instance = form.save(commit=False)
			instance.datetime = datetime.datetime.now()
			instance.user = request.user
			instance.save()
			messages.success(request, f'Aumeta sucessu.')
			if group == "staff": return redirect('leave-s-detail', hashid=hashid)
			elif group == "unit": return redirect('leave-c-detail', hashid=hashid)
	else: form = LeaveDelegateForm1(instance=objects)
	context = {
		'c_emp': c_emp, 'empdiv': empdiv, 'leave': leave, 'form': form, 'page': 'delegate',
		'title': 'Delega ba', 'legend': 'Delega ba'
	}
	return render(request, 'leave/form.html', context)
###
@login_required
def LeaveDelegConfirm(request, hashid):
	group = request.user.groups.all()[0].name
	c_emp = c_staff(request.user)
	empdiv = CurEmpDivision.objects.get(employee=c_emp)
	objects = get_object_or_404(LeaveDelegate, hashed=hashid)
	leave = objects.leave
	if request.method == 'POST':
		form = LeaveDelegateForm2(request.POST, instance=objects)
		if form.is_valid():
			obs = form.cleaned_data.get('obs')
			instance = form.save(commit=False)
			instance.is_confirm = True
			instance.datetime = datetime.datetime.now()
			instance.user = request.user
			instance.save()
			messages.success(request, f'Aumeta sucessu.')
			return redirect('leave-deleg-detail', hashid=hashid)
	else: form = LeaveDelegateForm2(instance=objects)
	context = {
		'c_emp': c_emp, 'empdiv': empdiv, 'leave': objects.leave, 'form': form, 'page': 'delegate',
		'title': 'Konsiente ba Delegasaun Servisu', 'legend': 'Konsiente ba Delegasaun Servisu'
	}
	return render(request, 'leave/form.html', context)

@login_required
def LeaveDelegConfirm2(request, hashid):
	group = request.user.groups.all()[0].name
	objects = get_object_or_404(LeaveDelegate, hashed=hashid)
	if objects.obs == 'Sim':
		objects.is_confirm2 =  True
	objects.save()
	leave = objects.leave
	leave.is_delegate = True
	if objects.obs == 'Lae':
		leave.is_send = False
	leave.save()
	messages.success(request, f'Konfirma ona.')
	return redirect('leave-deleg-detail', hashid=hashid)

@login_required
def LeaveDelegCancel(request, hashid):
	group = request.user.groups.all()[0].name
	objects = get_object_or_404(LeaveDelegate, hashed=hashid)
	objects.is_confirm =  False
	objects.is_confirm2 =  False
	objects.save()
	messages.success(request, f'Konfirmasaun cancela.')
	return redirect('leave-deleg-detail', hashid=hashid)
